@@ -1,9 +1,9 @@
-/* $Header: /var/cvs/mbdyn/mbdyn/mbdyn-1.0/libraries/libmbmath/gradienttest.cc,v 1.4 2015/06/25 18:34:18 masarati Exp $ */
+/* $Header: /var/cvs/mbdyn/mbdyn/mbdyn-1.0/libraries/libmbmath/gradienttest.cc,v 1.6 2017/01/12 14:43:53 masarati Exp $ */
 /*
  * MBDyn (C) is a multibody analysis code.
  * http://www.mbdyn.org
  *
- * Copyright (C) 1996-2015
+ * Copyright (C) 1996-2017
  *
  * Pierangelo Masarati	<masarati@aero.polimi.it>
  * Paolo Mantegazza	<mantegazza@aero.polimi.it>
@@ -31,7 +31,7 @@
 
 /*
  AUTHOR: Reinhard Resch <r.resch@secop.com>
-        Copyright (C) 2013(-2015) all rights reserved.
+        Copyright (C) 2013(-2017) all rights reserved.
 
         The copyright of this code is transferred
         to Pierangelo Masarati and Paolo Mantegazza
@@ -612,7 +612,37 @@ void testGradient2() {
     std::cout << "w=" << w << std::endl;
     std::cout << "w2=" << w2 << std::endl;
 }
+#if 0
+void testGradient3(index_type N)
+{
+    srand(0);
 
+    LocalDofMap dof;
+    Gradient<N_SIZE> u, v, w, f;
+
+    u.SetValuePreserve(random1() * 10);
+    v.SetValuePreserve(random1() * 3);
+    w.SetValuePreserve(random1() * 0.01);
+
+    u.DerivativeResizeReset(&dof, N, MapVectorBase::GLOBAL, 0.);
+    v.DerivativeResizeReset(&dof, N, MapVectorBase::GLOBAL, 0.);
+    w.DerivativeResizeReset(&dof, N, MapVectorBase::GLOBAL, 0.);
+
+
+    doublereal t_AD = 0., t_C = 0.;
+
+    for (int i = 0; i < NLoops; ++i) {
+    	const doublereal e = random1();
+    	doublereal start, stop;
+
+    	tic(start);
+    	func3(u, v, w, e, f);
+    	tic(stop);
+
+    	t_AD += stop - start;
+    }
+}
+#endif
 void testGradientCopy(int N) {
 	LocalDofMap map1, map2;
 	bool bFirst = true;
