@@ -1,9 +1,9 @@
-/* $Header: /var/cvs/mbdyn/mbdyn/mbdyn-1.0/libraries/libmbutil/parser.cc,v 1.87 2016/03/09 17:21:00 masarati Exp $ */
+/* $Header: /var/cvs/mbdyn/mbdyn/mbdyn-1.0/libraries/libmbutil/parser.cc,v 1.90 2017/01/12 14:44:05 masarati Exp $ */
 /*
  * MBDyn (C) is a multibody analysis code.
  * http://www.mbdyn.org
  *
- * Copyright (C) 1996-2015
+ * Copyright (C) 1996-2017
  *
  * Pierangelo Masarati	<masarati@aero.polimi.it>
  * Paolo Mantegazza	<mantegazza@aero.polimi.it>
@@ -1003,36 +1003,7 @@ HighParser::IsWord(const HighParser::WordSet& ws)
 TypedValue
 HighParser::GetValue(const TypedValue& vDefVal)
 {
-	const char sFuncName[] = "HighParser::GetValue()";
-
-	if (CurrToken != HighParser::ARG) {
-		silent_cerr("Parser error in "
-			<< sFuncName << ", arg expected at line "
-			<< GetLineData() << std::endl);
-		throw HighParser::ErrIntegerExpected(MBDYN_EXCEPT_ARGS);
-	}
-
-	TypedValue v(vDefVal);
-
-	try {
-		v = MathP.Get(*pIn, v);
-	}
-	catch (TypedValue::ErrWrongType& e) {
-		silent_cerr(sFuncName << ": " << e.what() << " at line "
-			<< GetLineData() << std::endl);
-		throw e;
-	}
-	catch (MathParser::ErrGeneric& e) {
-		silent_cerr(sFuncName << ": error return from MathParser at line "
-			<< GetLineData() << std::endl);
-		throw e;
-	}
-	catch (...) {
-		throw;
-	}
-
-	NextToken(sFuncName);
-	return v;
+	return GetValue<range_any<TypedValue> >(vDefVal, range_any<TypedValue>());
 }
 
 bool
@@ -1076,19 +1047,15 @@ HighParser::GetYesNoOrBool(bool bDefval)
 }
 
 integer
-HighParser::GetInt(int iDefVal)
+HighParser::GetInt(integer iDefVal)
 {
-	TypedValue v(iDefVal);
-	v = GetValue(v);
-	return v.GetInt();
+	return GetInt<range_any<integer> >(iDefVal, range_any<integer>());
 }
 
 doublereal
 HighParser::GetReal(const doublereal& dDefVal)
 {
-	TypedValue v(dDefVal);
-	v = GetValue(v);
-	return v.GetReal();
+	return GetReal<range_any<doublereal> >(dDefVal, range_any<doublereal>());
 }
 
 mbsleep_t
