@@ -1,9 +1,9 @@
-/* $Header: /var/cvs/mbdyn/mbdyn/mbdyn-1.0/mbdyn/aero/rotor.cc,v 1.141 2016/02/17 15:39:53 masarati Exp $ */
+/* $Header: /var/cvs/mbdyn/mbdyn/mbdyn-1.0/mbdyn/aero/rotor.cc,v 1.144 2017/09/26 22:58:54 masarati Exp $ */
 /*
  * MBDyn (C) is a multibody analysis code.
  * http://www.mbdyn.org
  *
- * Copyright (C) 1996-2015
+ * Copyright (C) 1996-2017
  *
  * Pierangelo Masarati	<masarati@aero.polimi.it>
  * Paolo Mantegazza	<mantegazza@aero.polimi.it>
@@ -1173,43 +1173,76 @@ GlauertRotor::GetInducedVelocity(Elem::Type type,
 	doublereal dr, dp;
 	GetPos(X, dr, dp);
 
+	// recall that tan(dChi) = dMu/dLambda
+
 	doublereal k1, k2 = 0.;
 	switch (gtype) {
 	case GLAUERT:
+		// NASA-TM-102219: attributed to Drees et al.
 		k1 = 4./3.*(1. - 1.8*dMu*dMu)*tan(dChi/2.);
 		break;
 
+#if 0
+	case WHEATLEY:
+		// NASA-TM-102219
+		k1 = 0.5;
+		break;
+#endif
+
 	case COLEMAN_ET_AL:
+		// NASA-TM-102219
+		// Gordon J. Leishman, "Principles of Helicopter Aerodynamics", 2nd Ed., 2006
+		// Wayne Johnson, "Rotorcraft Aeromechanics", 2013
 		k1 = tan(dChi/2.);
 		break;
 
 	case DREES_1:
-		// FIXME: divide by zero?
-		k1 = 4./3.*(1 - cos(dChi) - 1.8*dMu*dMu)/sin(dChi);
+	case DREES_2:
+		// Gordon J. Leishman, "Principles of Helicopter Aerodynamics", 2nd Ed., 2006
+		// Wayne Johnson, "Rotorcraft Aeromechanics", 2013
+		// k1 = 4./3.*(1 - cos(dChi) - 1.8*dMu*dMu)/sin(dChi); // risk of division by zero...
+		k1 = 4./3.*(tan(dChi/2.) - 1.8*dLambda*dMu/cos(dChi));
 		k2 = -2.*dMu;
 		break;
 
 	case PAYNE:
-		k1 = 4./3.*(dMu/dLambda/(1.2 + dMu/dLambda));
+		// NASA-TM-102219
+		// Gordon J. Leishman, "Principles of Helicopter Aerodynamics", 2nd Ed., 2006
+		// k1 = 4./3.*(dMu/dLambda/(1.2 + dMu/dLambda));
+		// reduce risk of division by zero
+		k1 = 4./3.*dMu/(1.2*dLambda + dMu);
 		break;
 
 	case WHITE_AND_BLAKE:
+		// NASA-TM-102219
+		// Gordon J. Leishman, "Principles of Helicopter Aerodynamics", 2nd Ed., 2006
+		// Wayne Johnson, "Rotorcraft Aeromechanics", 2013
 		k1 = sqrt(2.)*sin(dChi);
 		break;
 
 	case PITT_AND_PETERS:
-		k1 = 15.*M_PI/23.*tan(dChi/2.);
+		// NASA-TM-102219
+		// Gordon J. Leishman, "Principles of Helicopter Aerodynamics", 2nd Ed., 2006: "23" instead of "32"...
+		k1 = 15.*M_PI/32.*tan(dChi/2.);
 		break;
 
 	case HOWLETT:
+		// NASA-TM-102219
+		// Gordon J. Leishman, "Principles of Helicopter Aerodynamics", 2nd Ed., 2006
 		k1 = pow(sin(dChi), 2);
 		break;
 
+#if 0
 	case DREES_2: {
+		// Jianhua Zhang, "Active-Passive Hybrid Optimization of Rotor Blades With Trailing Edge Flaps", PhD Thesis, PSU, 2001
+		// in the end, it is identical to Drees' as of Wayne Johnson and Gordon J. Leishman
+		// FIXME: what if dMu ~ 0?
 		doublereal dLdM = dLambda/dMu;
-		k1 = 4./3.*((1. - 1.8*dMu*dMu)*sqrt(1. + dLdM*dLdM - dLdM));
+		// k1 = 4./3.*((1. - 1.8*dMu*dMu)*sqrt(1. + dLdM*dLdM - dLdM));
+		k1 = 4./3.*((1. - 1.8*dMu*dMu)*sqrt(1. + dLdM*dLdM) - dLdM);
 		k2 = -2.*dMu;
 		} break;
+#endif
 
 	default:
 		throw ErrGeneric(MBDYN_EXCEPT_ARGS);
@@ -2661,6 +2694,7 @@ ReadRotor(DataManager* pDM,
 				gtype = GlauertRotor::HOWLETT;
 
 			} else if (HP.IsKeyWord("drees" "2")) {
+				silent_cerr("warning, \"drees 2\" deprecated at line " << HP.GetLineData() << "; use \"drees\" instead" << std::endl);
 				gtype = GlauertRotor::DREES_2;
 
 			} else {
