@@ -1,9 +1,9 @@
-/* $Header: /var/cvs/mbdyn/mbdyn/mbdyn-1.0/mbdyn/base/dataman.cc,v 1.153 2016/02/17 15:40:04 masarati Exp $ */
+/* $Header: /var/cvs/mbdyn/mbdyn/mbdyn-1.0/mbdyn/base/dataman.cc,v 1.157 2017/05/29 17:50:43 masarati Exp $ */
 /*
  * MBDyn (C) is a multibody analysis code.
  * http://www.mbdyn.org
  *
- * Copyright (C) 1996-2015
+ * Copyright (C) 1996-2017
  *
  * Pierangelo Masarati	<masarati@aero.polimi.it>
  * Paolo Mantegazza	<mantegazza@aero.polimi.it>
@@ -104,7 +104,7 @@ MathPar(HP.GetMathParser()),
 pSolver(pS),
 DrvHdl(HP.GetMathParser()),
 OutHdl(sOutputFileName, 0),
-pXCurr(0), pXPrimeCurr(0), 
+pXCurr(0), pXPrimeCurr(0),
 /* Inverse Dynamics: */
 pXPrimePrimeCurr(0),
 pLambdaCurr(0),
@@ -154,19 +154,17 @@ bNetCDFnoText(false),
 Var_Step(0),
 Var_Time(0),
 Var_TimeStep(0),
+Var_Eig_lStep(0),
+Var_Eig_dTime(0),
+Var_Eig_dCoef(0),
+Var_Eig_dAplus(0),
+Var_Eig_dAminus(0),
+Var_Eig_dAlpha(0),
+Var_Eig_Idx(0),
+Var_Eig_dVR(0),
+Var_Eig_dVL(0),
 #endif // USE_NETCDF
 od(EULER_123),
-#if defined(USE_ADAMS) || defined(USE_MOTIONVIEW)
-iOutputBlock(1),
-#endif /* defined(USE_ADAMS) || defined(USE_MOTIONVIEW) */
-#ifdef USE_ADAMS
-sAdamsModelName(0),
-bAdamsVelocity(false),
-bAdamsAcceleration(false),
-iAdamsOutputNodes(0),
-iAdamsOutputParts(0),
-adamsNoab(0),
-#endif /* USE_ADAMS */
 
 #ifdef USE_SOCKET
 SocketUsersTimeout(0),
@@ -220,7 +218,7 @@ Dofs()
 	HP.GetMathParser().RegisterPlugIn("element", elem_priv_plugin, this);
 
 	/* registra il namespace del modello */
-	
+
 	HP.GetMathParser().RegisterNameSpace(new ModelNameSpace(this));
 
 	/* Setta il tempo al valore iniziale */
@@ -517,21 +515,6 @@ Dofs()
 	}
 #endif /* DEBUG */
 
-#ifdef USE_ADAMS
-	/* Se richiesto, inizializza il file di output AdamsRes */
-	if (bAdamsOutput()) {
-		AdamsResOutputInit();
-		AdamsResOutput(iOutputBlock, "INPUT", "MBDyn");
-	}
-#endif /* USE_ADAMS */
-
-#ifdef USE_MOTIONVIEW
-	if (bMotionViewOutput()) {
-		MotionViewResOutputInit(sOutputFileName);
-		MotionViewResOutput(1, "INPUT", "MBDyn");
-	}
-#endif /* USE_MOTIONVIEW */
-
 	if (bAbortAfterInput) {
 		silent_cout("Only input is required" << std::endl);
 		return;
@@ -625,23 +608,6 @@ Dofs()
 	}
 #endif /* DEBUG */
 
-	/* Se richiesto, esegue l'output delle condizioni iniziali */
-#if defined(USE_ADAMS) || defined(USE_MOTIONVIEW)
-	iOutputBlock++;
-#endif /* defined(USE_ADAMS) || defined(USE_MOTIONVIEW) */
-
-#ifdef USE_ADAMS
-	if (bAdamsOutput()) {
-		AdamsResOutput(iOutputBlock, "INITIAL CONDITIONS", "MBDyn");
-	}
-#endif /* USE_ADAMS */
-
-	/* Se richiesto, esegue l'output delle condizioni iniziali */
-#ifdef USE_MOTIONVIEW
-	if (bMotionViewOutput()) {
-		MotionViewResOutput(iOutputBlock, "INITIAL CONDITIONS", "MBDyn");
-	}
-#endif /* USE_ADAMS */
 
 } /* End of DataManager::DataManager() */
 
@@ -661,18 +627,6 @@ DataManager::~DataManager(void)
 		MakeRestart();
 	}
 
-#ifdef USE_ADAMS
-	if (bAdamsOutput()) {
-		AdamsResOutputFini();
-	}
-#endif /* USE_ADAMS */
-
-#ifdef USE_MOTIONVIEW
-	if (bMotionViewOutput()) {
-		MotionViewResOutputFini();
-	}
-#endif /* USE_MOTIONVIEW */
-
 	if (sSimulationTitle != 0) {
 		SAFEDELETEARR(sSimulationTitle);
 		sSimulationTitle = 0;
@@ -727,6 +681,14 @@ DataManager::OutputOpen(const OutputHandler::OutFiles o)
 	}
 }
 
+void
+DataManager::OutputEigOpen(const std::string& postfix)
+{
+	if (!OutHdl.IsOpen(OutputHandler::EIGENANALYSIS)) {
+		OutHdl.Open(OutputHandler::EIGENANALYSIS, postfix);
+		ASSERT(OutHdl.IsOpen(OutputHandler::EIGENANALYSIS));
+	}
+}
 
 bool
 DataManager::bOutput(ResType t) const
@@ -858,7 +820,7 @@ void DataManager::MakeRestart(void)
 	{
 		dynamic_cast<const Elem2Param *>(n->second)->RestartBind(OutHdl.Restart());
 	}
-		
+
 	OutHdl.Restart() << "end: elements;" << std::endl;
 
 	if (saveXSol) {
@@ -985,4 +947,3 @@ DataManager::PopCurrData(const std::string& name)
 
 	return pMNS->PopCurrData(name);
 }
-
