@@ -1,9 +1,9 @@
-/* $Header: /var/cvs/mbdyn/mbdyn/mbdyn-1.0/mbdyn/base/dataman.h,v 1.194 2016/04/24 09:26:13 masarati Exp $ */
+/* $Header: /var/cvs/mbdyn/mbdyn/mbdyn-1.0/mbdyn/base/dataman.h,v 1.202 2017/09/09 09:20:12 masarati Exp $ */
 /*
  * MBDyn (C) is a multibody analysis code.
  * http://www.mbdyn.org
  *
- * Copyright (C) 1996-2015
+ * Copyright (C) 1996-2017
  *
  * Pierangelo Masarati	<masarati@aero.polimi.it>
  * Paolo Mantegazza	<mantegazza@aero.polimi.it>
@@ -107,7 +107,7 @@ protected:
 	/* Puntatori ai vettori soluzione durante il passo */
 	mutable VectorHandler* pXCurr;
 	mutable VectorHandler* pXPrimeCurr;
-	
+
 	/* used by inverse dynamics: */
 	mutable VectorHandler* pXPrimePrimeCurr;
 	mutable VectorHandler* pLambdaCurr;
@@ -193,8 +193,6 @@ public:
 		RES_NONE	= 0x00,
 		RES_TEXT	= 0x01,
 		RES_NETCDF	= 0x02,
-		RES_ADAMS	= 0x04,
-		RES_MOTIONVIEW	= 0x08
 	};
 
 	bool bOutput(ResType t) const;
@@ -210,26 +208,26 @@ protected:
 	NcVar *Var_Step;
 	NcVar *Var_Time;
 	NcVar *Var_TimeStep;
+
+	/* for eigenanalysis output */
+
+	const NcDim *m_Dim_Eig_iSize;
+	const NcDim *m_Dim_Eig_iComplex;
+
+	NcVar *Var_Eig_lStep;
+	NcVar *Var_Eig_dTime;
+	NcVar *Var_Eig_dCoef;
+	NcVar *Var_Eig_dAplus;
+	NcVar *Var_Eig_dAminus;
+	NcVar *Var_Eig_dAlpha;
+	NcVar *Var_Eig_Idx;
+	NcVar *Var_Eig_dVR;
+	NcVar *Var_Eig_dVL;
+
 	/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
 #endif /* USE_NETCDF */
 	OrientationDescription od;
 
-#if defined(USE_ADAMS) || defined(USE_MOTIONVIEW)
-	mutable integer iOutputBlock;
-#endif /* defined(USE_ADAMS) || defined(USE_MOTIONVIEW) */
-
-#ifdef USE_ADAMS
-	char *sAdamsModelName;
-	bool bAdamsVelocity, bAdamsAcceleration;
-	unsigned int iAdamsOutputNodes;
-	unsigned int iAdamsOutputParts;
-	std::streambuf::pos_type adamsNoab;
-#endif /* USE_ADAMS */
-
-#ifdef USE_MOTIONVIEW
-	/* nothing yet */
-#endif /* USE_MOTIONVIEW */
-
 protected:
 	/* chiamate dal costruttore per leggere i relativi articoli */
 	void ReadControl(MBDynParser& HP, const char* sInputFileName);
@@ -263,7 +261,7 @@ protected:
 
 	void DofOwnerSet(void);
 	void DofOwnerInit(void);
-	
+
 	/* inverse dynamics: */
 	void IDDofOwnerSet(void);
 
@@ -321,7 +319,7 @@ public:
 		VectorHandler& XPrimeCurr,
 		VectorHandler& XPrimePrimeCurr,
 		VectorHandler& LambdaCurr);
-	
+
 	/* Restituisce l'ostream al file di output,
 	 * usato dai vari metodi per scrivere il log del calcolo */
 	std::ostream& GetOutFile(void) const { return OutHdl.Output(); };
@@ -363,8 +361,8 @@ public:
 
 	/* Elem residual, equilibrium with no constraints */
 	virtual void AssRes(VectorHandler& ResHdl);
-	
-	/* Constraint Jacobian matrix*/	
+
+	/* Constraint Jacobian matrix*/
 	virtual void AssConstrJac(MatrixHandler& JacHdl);
 	// end of inverse dynamics
 
@@ -390,7 +388,7 @@ protected:
 		VecIter<Elem *> &Iter,
 		SubVectorHandler& WorkVec,
 		InverseDynamics::Order iOrder);
-	
+
 	void AssRes(VectorHandler& ResHdl,
 		VecIter<Elem *> &Iter,
 		SubVectorHandler& WorkVec);
@@ -414,6 +412,8 @@ public:
 
 public:
 	virtual void OutputPrepare(void);
+	virtual void OutputEigPrepare(const integer iNumAnalyses,
+			const integer iSize);
 
 	/* stampa i risultati */
 	virtual bool
@@ -424,23 +424,40 @@ public:
 
 	void OutputOpen(const OutputHandler::OutFiles out);
 
-#ifdef USE_ADAMS
-	/* MSC's ADAMS/View .res output */
-	bool bAdamsOutput(void) const;
-	void AdamsResOutputInit(void);
-	void AdamsResOutput(integer iBlock, const char *type,
-			const char *id) const;
-	void AdamsResOutputFini(void) const;
-#endif /* USE_ADAMS */
+	/* Eigenanalysis output */
+	void OutputEigOpen(const std::string& postfix);
+	void
+	OutputEigParams(const doublereal& dTime,
+			const doublereal& dCoef,
+			const unsigned uCurrEigSol,
+			const int iResultsPrecision);
+	void
+	OutputEigFullMatrices(const MatrixHandler* pmMatA,
+			const MatrixHandler* pmMatB,
+			const unsigned uCurrEigSol,
+			const int iMatrixPrecision);
+	void
+	OutputEigSparseMatrices(const MatrixHandler* pmMatA,
+			const MatrixHandler* pmMatB,
+			const unsigned uCurrEigSol,
+			const int iMatrixPrecision);
+	void
+	OutputEigNaiveMatrices(const MatrixHandler* pmMatA,
+			const MatrixHandler* pmMatB,
+			const unsigned uCurrEigSol,
+			const int iMatrixPrecision);
+	void
+	OutputEigenvectors(const VectorHandler *pBeta,
+			const VectorHandler& R, const VectorHandler& I,
+			const doublereal& dShiftR,
+			const MatrixHandler *pVL, const MatrixHandler& VR,
+			const std::vector<bool>& vOut,
+			const unsigned uCurrEigSol,
+			const int iResultsPrecision);
 
-#ifdef USE_MOTIONVIEW
-	/* Altair's Motion View output */
-	bool bMotionViewOutput(void) const;
-	void MotionViewResOutputInit(const char *sOutputFileName);
-	void MotionViewResOutput(integer iBlock, const char *type,
-			const char *id) const;
-	void MotionViewResOutputFini(void) const;
-#endif /* USE_MOTIONVIEW */
+	void OutputEigGeometry(const unsigned uCurrSol,
+			const int iResultsPrecision);
+	bool OutputEigClose(void);
 
 	/* Prepara la soluzione con i valori iniziali */
 	void SetValue(VectorHandler& X, VectorHandler& XP);
@@ -453,11 +470,11 @@ public:
 	virtual void AfterPredict(void) const;
 	virtual void Update(void) const;
 	virtual void AfterConvergence(void) const;
-	
+
 	/* Inverse Dynamics: */
 	virtual void Update(InverseDynamics::Order iOrder) const;
 	virtual void IDAfterConvergence(void) const;
-	virtual void IDSetTest(NonlinearSolverTestRange *pResTest, NonlinearSolverTestRange *pSolTest);
+	virtual void IDSetTest(NonlinearSolverTestRange *pResTest, NonlinearSolverTestRange *pSolTest, bool bFullResTest);
 
 	void bSetStaticModel(bool b) {
 		bStaticModel = b;
@@ -644,9 +661,15 @@ public:
 	const DataManager::ElemDataStructure& GetElemDataStructure(Elem::Type Typ) const { return ElemData[Typ]; };
 
 	/* buffer per accesso a input/output speciali */
-	const std::vector<doublereal>& GetBufIn(unsigned uL);
+	std::vector<doublereal>& GetBufIn(unsigned uL);
 	const std::vector<doublereal>& GetBufOut(unsigned uL) const;
 
+	/* low-level variant (use at own risk) */
+	doublereal * GetBufInRaw(unsigned uL);
+	void SetBufInRaw(unsigned uL, integer n, const doublereal *p);
+	const doublereal * GetBufOutRaw(unsigned uL) const;
+	void SetBufOutRaw(unsigned uL, integer n, const doublereal *p);
+
 	/* pseudocostruttore */
 	void ElemManager(void);
 	void ElemManagerDestructor(void);
@@ -708,7 +731,7 @@ protected:
 		NodeContainerType NodeContainer;
 		NodeMapToListType NodeMapToList;
 	} NodeData[Node::LASTNODETYPE];
-	
+
 	Node ** InsertNode(NodeDataStructure& nodedata, unsigned int uLabel, Node * pN) {
 		nodedata.NodeContainer.push_back(NodeContainerType::value_type(uLabel, pN));
 		nodedata.NodeMapToList[uLabel] = --nodedata.NodeContainer.end();
@@ -1097,4 +1120,3 @@ extern OrientationDescription
 ReadOptionalOrientationDescription(DataManager *pDM, MBDynParser& HP);
 
 #endif /* DATAMAN_H */
-
