@@ -1,9 +1,9 @@
-/* $Header: /var/cvs/mbdyn/mbdyn/mbdyn-1.0/mbdyn/base/drive_.cc,v 1.113 2016/04/24 09:26:13 masarati Exp $ */
+/* $Header: /var/cvs/mbdyn/mbdyn/mbdyn-1.0/mbdyn/base/drive_.cc,v 1.118 2017/08/28 10:34:39 masarati Exp $ */
 /*
  * MBDyn (C) is a multibody analysis code.
  * http://www.mbdyn.org
  *
- * Copyright (C) 1996-2015
+ * Copyright (C) 1996-2017
  *
  * Pierangelo Masarati	<masarati@aero.polimi.it>
  * Paolo Mantegazza	<mantegazza@aero.polimi.it>
@@ -703,7 +703,7 @@ iNumCycles(iNumCyc), dInitialValue(d4), bNeverEnd(false)
 		dFinalValue = dInitialValue;
 
 	/* Onde di coseno che continuano all'infinito */
-	} else if(iNumCycles == 0) {
+	} else if (iNumCycles == 0) {
 		dEndTime = 0.;
 		bNeverEnd = true;
 
@@ -1418,6 +1418,10 @@ void DriveCallerRead::ReadOutput(DriveCaller* pDC, const DataManager* pDM, MBDyn
 		}
 	}
 
+	if (fOutput) {
+		fOutput |= DriveCaller::OUTPUT;
+	}
+    
 	pDC->SetOutputFlag(fOutput);
 
 	flag fTrace = 0;
@@ -1468,6 +1472,10 @@ void DriveCallerRead::ReadOutput(DriveCaller* pDC, const DataManager* pDM, MBDyn
 		}
 	}
 
+	if (fTrace) {
+		fTrace |= DriveCaller::TRACE;
+	}
+    
 	pDC->SetTraceFlag(fTrace);
 }
 
@@ -1888,7 +1896,7 @@ DoubleRampDCR::Read(const DataManager* pDM, MBDynParser& HP, bool bDeferred)
 	doublereal dDescendingSlope = HP.GetReal(-1.);
 	DEBUGCOUT("Descending Slope Value: " << dDescendingSlope << std::endl);
 
-	doublereal dDescendingInitialTime = std::numeric_limits<double>::max();
+	doublereal dDescendingInitialTime = std::numeric_limits<doublereal>::max();
 	if (!HP.IsKeyWord("forever")) {
 		dDescendingInitialTime = HP.GetReal();
 	}
@@ -1904,7 +1912,14 @@ DoubleRampDCR::Read(const DataManager* pDM, MBDynParser& HP, bool bDeferred)
 		throw DataManager::ErrGeneric(MBDYN_EXCEPT_ARGS);
 	}
 
-	doublereal dDescendingFinalTime = HP.GetReal();
+	doublereal dDescendingFinalTime;
+	if (HP.IsKeyWord("forever")) {
+		dDescendingFinalTime = std::numeric_limits<doublereal>::max();
+
+	} else {
+		dDescendingFinalTime = HP.GetReal();
+	}
+
 	DEBUGCOUT("Descending Final time: " << dDescendingFinalTime << std::endl);
 
 	if (dDescendingFinalTime <= dDescendingInitialTime) {
@@ -2855,14 +2870,21 @@ FileDCR::Read(const DataManager* pDM, MBDynParser& HP, bool bDeferred)
 	}
 
 	integer id = 1;
-	if (HP.IsArg()) {
-		id = HP.GetInt(id);
-		if (id < 1 || id > pDrv->iGetNumDrives()) {
-			silent_cerr("line " << HP.GetLineData()
-				<< ": invalid column number " << id
-				<< " (must be between 1 and " 
-				<< pDrv->iGetNumDrives() << ")" << std::endl);
-			throw DataManager::ErrGeneric(MBDYN_EXCEPT_ARGS);
+		
+	const char *s = HP.IsWord(fileDriveCallerTypeWordSet);
+	if (s != NULL) {
+		FileDriveCallerTypeMap::iterator it = fileDriveCallerTypeMap.find(std::string(s));
+		id = it->second->Read(pDM, HP, pDrv);
+	} else {
+		if (HP.IsArg()) {
+			id = HP.GetInt(id);
+			if (id < 1 || id > pDrv->iGetNumDrives()) {
+				silent_cerr("line " << HP.GetLineData()
+					<< ": invalid column number " << id
+					<< " (must be between 1 and "
+					<< pDrv->iGetNumDrives() << ")" << std::endl);
+				throw DataManager::ErrGeneric(MBDYN_EXCEPT_ARGS);
+			}
 		}
 	}
 
@@ -2879,6 +2901,37 @@ FileDCR::Read(const DataManager* pDM, MBDynParser& HP, bool bDeferred)
 	return pDC;
 }
 
+/*----------------------------------------------------------------------------
+management of FileDriveCaller type
+------------------------------------------------------------------------------
+
+Coded by Luca Conti (May 2017)
+*/
+
+FileDriveCallerTypeMap fileDriveCallerTypeMap;
+FileDriveCallerTypeWordSet fileDriveCallerTypeWordSet;
+
+/* FileDriveCaller type parsing checker: allows the parser
+to understand if the next keyword is a FileDriveCaller type */
+bool FileDriveCallerTypeWordSet::IsWord(const std::string& s) const {
+		return fileDriveCallerTypeMap.find(std::string(s)) != fileDriveCallerTypeMap.end();
+	};
+
+bool setFileDriveCallerType(const char *name, FileDriveCallerTypeReader *rf){
+	pedantic_cout("registering FileDriveCaller type \"" << name << "\""
+		<< std::endl );
+	return fileDriveCallerTypeMap.insert(FileDriveCallerTypeMap::value_type(name, rf)).second;
+}
+
+void DestroyFileDriveCallerTypes(void){
+	for (FileDriveCallerTypeMap::iterator i = fileDriveCallerTypeMap.begin(); i != fileDriveCallerTypeMap.end(); ++i) {
+		delete i->second;
+	}
+	fileDriveCallerTypeMap.clear();
+}
+
+/*---------------------------------------------------------------------------*/
+
 struct PeriodicDCR : public DriveCallerRead {
 	DriveCaller *
 	Read(const DataManager* pDM, MBDynParser& HP, bool bDeferred);
