@@ -1,9 +1,9 @@
-/* $Header: /var/cvs/mbdyn/mbdyn/mbdyn-1.0/mbdyn/base/drive_.h,v 1.55 2015/08/24 20:47:18 masarati Exp $ */
+/* $Header: /var/cvs/mbdyn/mbdyn/mbdyn-1.0/mbdyn/base/drive_.h,v 1.60 2017/09/09 09:17:32 masarati Exp $ */
 /*
  * MBDyn (C) is a multibody analysis code.
  * http://www.mbdyn.org
  *
- * Copyright (C) 1996-2015
+ * Copyright (C) 1996-2017
  *
  * Pierangelo Masarati	<masarati@aero.polimi.it>
  * Paolo Mantegazza	<mantegazza@aero.polimi.it>
@@ -35,6 +35,7 @@
 #define DRIVE__H
 
 /* include generali */
+#include "parser.h"
 #include <sstream>
 #ifdef USE_EE
 #include <thread>
@@ -51,6 +52,8 @@
 #include "withlab.h"
 
 #include "drive.h"
+#include "filedrv.h"
+
 
 /* StringDriveCaller - begin */
 
@@ -103,38 +106,22 @@ StringDriveCaller::dGet(const doublereal& dVar) const
 {
 	DriveCaller::pDrvHdl->SetVar(dVar);
 
-#ifdef USE_EE
-	return m_expr->Get()->Eval().GetReal();
-#else // ! USE_EE
-#ifdef DEBUG
-
-	/* La variabile temporanea serve solo per il debug;
-	 * il codice in effetti avrebbe dovuto essere:
-
-	return DriveCaller::pDrvHdl->dGet(InStr);
-
-	 * Tuttavia si ritiene che la modifica non sia troppo onerosa */
-
-	do {
-		std::istringstream in(sEvalStr);
-		InputStream In(in);
-		silent_cout("StringDriveCaller::dGet(): "
-			<< DriveCaller::pDrvHdl->dGet(In) << std::endl);
-	} while (0);
-#endif /* DEBUG */
-
-	std::istringstream in(sEvalStr);
-	InputStream In(in);
-
-	return DriveCaller::pDrvHdl->dGet(In);
-#endif // ! USE_EE
+	return dGet();
 }
 
 inline doublereal
 StringDriveCaller::dGet(void) const
 {
 #ifdef USE_EE
-	return m_expr->Get()->Eval().GetReal();
+	doublereal val;
+	try {
+		val = m_expr->Get()->Eval().GetReal();
+	} catch (MBDynErrBase& e) {
+		silent_cerr("StringDriveCaller::dGet(): " << e.what() << std::endl);
+		throw e;
+	}
+
+	return val;
 #else // ! USE_EE
 	std::istringstream in(sEvalStr);
 	InputStream In(in);
@@ -1401,7 +1388,7 @@ DirectDriveCaller::dGetP(const doublereal& dVar) const
 	return 1.;
 }
 
-/* MeterDriveCaller - end */
+/* DirectDriveCaller - end */
 
 
 /* PiecewiseLinearDriveCaller - begin */
@@ -1713,5 +1700,37 @@ PostponedDriveCaller::dGetP(const doublereal& dVar) const
 
 /* PostponedDriveCaller - end */
 
-#endif /* DRIVE__H */
+/*----------------------------------------------------------------------------
+management of FileDriveCaller type
+------------------------------------------------------------------------------
 
+Coded by Luca Conti (May 2017)
+*/
+
+/*FileDriveCaller type reader: every content type must inherit
+from this struct and implement its own Read method*/
+struct FileDriveCallerTypeReader {
+	virtual integer Read(const DataManager* pDM, MBDynParser& HP, FileDrive* pDrv) = 0;
+	virtual ~FileDriveCallerTypeReader(void) { NO_OP; };
+};
+
+/*bag of FileDriveCaller type - every type is registered inside
+of it by using SetFileDriveCallerType(...)*/
+typedef std::map<std::string,FileDriveCallerTypeReader*> FileDriveCallerTypeMap;
+extern FileDriveCallerTypeMap fileDriveCallerTypeMap;
+
+/* FileDriveCaller type parsing checker: allows the parser
+to understand if the next keyword is a FileDriveCaller type */
+struct FileDriveCallerTypeWordSet : public HighParser::WordSet {
+	virtual bool IsWord(const std::string& s) const;
+};
+typedef struct FileDriveCallerTypeWordSet FileDriveCallerTypeWordSet;
+extern FileDriveCallerTypeWordSet fileDriveCallerTypeWordSet;
+
+/* registration function: call it to register a new FileDriveCaller type*/
+bool setFileDriveCallerType(const char *name, FileDriveCallerTypeReader *rf);
+
+/*deallocation of all FileDriveCaller types in fileDriveCallerTypeMap, if any was added*/
+void DestroyFileDriveCallerTypes(void);
+
+#endif /* DRIVE__H */
