@@ -1,9 +1,9 @@
-/* $Header: /var/cvs/mbdyn/mbdyn/mbdyn-1.0/mbdyn/base/extforce.cc,v 1.49 2015/06/25 18:36:36 masarati Exp $ */
+/* $Header: /var/cvs/mbdyn/mbdyn/mbdyn-1.0/mbdyn/base/extforce.cc,v 1.51 2017/08/03 11:49:02 masarati Exp $ */
 /* 
  * MBDyn (C) is a multibody analysis code. 
  * http://www.mbdyn.org
  *
- * Copyright (C) 2007-2015
+ * Copyright (C) 2007-2017
  *
  * Pierangelo Masarati	<masarati@aero.polimi.it>
  * Paolo Mantegazza	<mantegazza@aero.polimi.it>
@@ -886,12 +886,14 @@ ReadExtSocketHandler(DataManager* pDM,
 #ifdef USE_SOCKET
 	ExtFileHandlerBase *pEFH = 0;
 
-	bool bCreate = false;
+	bool bGotCreate(false);
+	bool bCreate(false);
 	unsigned short int port = (unsigned short int)-1; 
 	std::string host;
 	std::string path;
 
 	if (HP.IsKeyWord("create")) {
+		bGotCreate = true;
 		if (!HP.GetYesNo(bCreate)) {
 			silent_cerr("ExtSocketHandler"
 				"(" << uLabel << "): "
@@ -986,6 +988,10 @@ ReadExtSocketHandler(DataManager* pDM,
 		if (HP.IsKeyWord("udp")) {
 			socket_type = SOCK_DGRAM;
 
+			if (!bGotCreate) {
+				bCreate = true;
+			}
+
 		} else if (!HP.IsKeyWord("tcp")) {
 			silent_cerr("ExtSocketHandler(" << uLabel << "\"): "
 				"invalid socket type "
@@ -996,7 +1002,7 @@ ReadExtSocketHandler(DataManager* pDM,
 
 	if ((socket_type == SOCK_DGRAM) && !bCreate) {
 		silent_cerr("ExtSocketHandler(" << uLabel << "\"): "
-			"socket type=upd incompatible with create=no "
+			"socket type=udp incompatible with create=no "
 			"at line " << HP.GetLineData() << std::endl);
 		throw ErrGeneric(MBDYN_EXCEPT_ARGS);
 	}
