@@ -1,9 +1,9 @@
-/* $Header: /var/cvs/mbdyn/mbdyn/mbdyn-1.0/mbdyn/base/ginaccltp.h,v 1.34 2015/08/17 17:01:15 masarati Exp $ */
+/* $Header: /var/cvs/mbdyn/mbdyn/mbdyn-1.0/mbdyn/base/ginaccltp.h,v 1.36 2017/04/28 17:59:45 masarati Exp $ */
 /* 
  * MBDyn (C) is a multibody analysis code. 
  * http://www.mbdyn.org
  *
- * Copyright (C) 1996-2015
+ * Copyright (C) 1996-2017
  *
  * Pierangelo Masarati	<masarati@aero.polimi.it>
  * Paolo Mantegazza	<mantegazza@aero.polimi.it>
@@ -139,7 +139,7 @@ GiNaCElasticConstitutiveLaw<T, Tder>::GiNaCElasticConstitutiveLaw(
 	}
 	for (unsigned row = 0; row < dim; row++) {
 		for (unsigned col = 0; col < dim; col++) {
-			silent_cout("\t\tDer/Eps[" << row << "][" << col << "]:          \"" << gExprDEps[row][col] << "\"" << std::endl);
+			silent_cout("\t\tDer[" << row << "]/Eps[" << row << "][" << col << "]:          \"" << gExprDEps[row][col] << "\"" << std::endl);
 		}
 	}
 
@@ -466,7 +466,7 @@ GiNaCViscousConstitutiveLaw<T, Tder>::GiNaCViscousConstitutiveLaw(
 	}
 	for (unsigned row = 0; row < dim; row++) {
 		for (unsigned col = 0; col < dim; col++) {
-			silent_cout("\t\tDer/EpsPrime[" << row << "][" << col << "]:  \"" << gExprDEpsPrime[row][col] << "\"" << std::endl);
+			silent_cout("\t\tDer[" << row << "]/EpsPrime[" << row << "][" << col << "]:  \"" << gExprDEpsPrime[row][col] << "\"" << std::endl);
 		}
 	}
 
@@ -807,12 +807,12 @@ GiNaCViscoElasticConstitutiveLaw<T, Tder>::GiNaCViscoElasticConstitutiveLaw(
 	}
 	for (unsigned row = 0; row < dim; row++) {
 		for (unsigned col = 0; col < dim; col++) {
-			silent_cout("\t\tDer/Eps[" << row << "][" << col << "]:          \"" << gExprDEps[row][col] << "\"" << std::endl);
+			silent_cout("\t\tDer[" << row << "]/Eps[" << row << "][" << col << "]:          \"" << gExprDEps[row][col] << "\"" << std::endl);
 		}
 	}
 	for (unsigned row = 0; row < dim; row++) {
 		for (unsigned col = 0; col < dim; col++) {
-			silent_cout("\t\tDer/EpsPrime[" << row << "][" << col << "]:          \"" << gExprDEpsPrime[row][col] << "\"" << std::endl);
+			silent_cout("\t\tDer[" << row << "]/EpsPrime[" << row << "][" << col << "]:          \"" << gExprDEpsPrime[row][col] << "\"" << std::endl);
 		}
 	}
 
