@@ -1,9 +1,9 @@
-/* $Header: /var/cvs/mbdyn/mbdyn/mbdyn-1.0/mbdyn/base/invdataman.cc,v 1.56 2015/10/26 16:05:31 masarati Exp $ */
+/* $Header: /var/cvs/mbdyn/mbdyn/mbdyn-1.0/mbdyn/base/invdataman.cc,v 1.59 2017/09/09 09:20:12 masarati Exp $ */
 /*
  * MBDyn (C) is a multibody analysis code.
  * http://www.mbdyn.org
  *
- * Copyright (C) 1996-2015
+ * Copyright (C) 1996-2017
  *
  * Pierangelo Masarati	<masarati@aero.polimi.it>
  * Paolo Mantegazza	<mantegazza@aero.polimi.it>
@@ -42,6 +42,9 @@
 #include <strings.h>
 #include <time.h>
 
+/* for inertia element */
+#include <set>
+
 #include "dataman.h"
 #include "friction.h"
 
@@ -58,6 +61,7 @@
 
 /* temporary? */
 #include "beam.h"
+#include "inertia.h"
 
 /* To allow direct loading of modules */
 #include "modules.h"
@@ -72,6 +76,7 @@
 #include "jointreg.h"
 #include "Rot.hh"
 
+
 void 
 DataManager::LinkToSolution(VectorHandler& XCurr,
 	VectorHandler& XPrimeCurr,
@@ -678,6 +683,7 @@ DataManager::AssConstrRes(VectorHandler& ResHdl,
 				}
 			}
 		}
+
 		} break;
 
 	default:
@@ -695,8 +701,24 @@ void
 DataManager::AssRes(VectorHandler& ResHdl)
 {
 	DEBUGCOUT("Entering AssRes()" << std::endl);
-
 	AssRes(ResHdl, ElemIter, *pWorkVec);
+
+	for (ElemContainerType::iterator j = ElemData[Elem::INERTIA].ElemContainer.begin();
+		j != ElemData[Elem::INERTIA].ElemContainer.end(); ++j)
+	{
+		bool bActive(true);
+		Inertia *pI = Cast<Inertia>(j->second, true);
+		if (pI == 0) {
+			bActive = false;
+			pI = Cast<Inertia>(j->second, false);
+		}
+			if (pI && bActive)
+		{
+			ResHdl += j->second->AssRes(*pWorkVec, *pXCurr,
+				*pXPrimeCurr, *pXPrimePrimeCurr, 
+				InverseDynamics::INVERSE_DYNAMICS);
+		}
+	}
 }
 
 void
@@ -1086,7 +1108,7 @@ DataManager::iIDGetTotNumDofs(void) const
 }
 
 void
-DataManager::IDSetTest(NonlinearSolverTestRange *pResTest, NonlinearSolverTestRange *pSolTest)
+DataManager::IDSetTest(NonlinearSolverTestRange *pResTest, NonlinearSolverTestRange *pSolTest, bool bFullResTest)
 {
 	integer iFirstIndex = std::numeric_limits<integer>::max();
 	integer iLastIndex = -1;
@@ -1134,6 +1156,11 @@ DataManager::IDSetTest(NonlinearSolverTestRange *pResTest, NonlinearSolverTestRa
 		}
 	}
 
+	if (bFullResTest) {
+		// NOTE: assumes *ALL* residual elements need to be evaluated!  Use with care...
+		iFirstIndex = 0;
+	}
+
 	silent_cout("DataManager::IDSetTest(): ResTest range=[" << iFirstIndex + 1 << ":" << iLastIndex << "]" << std::endl);
 
 	pResTest->SetRange(iFirstIndex + 1, iLastIndex);
