@@ -1,9 +1,9 @@
-/* $Header: /var/cvs/mbdyn/mbdyn/mbdyn-1.0/mbdyn/base/invsolver.cc,v 1.50 2016/04/23 17:01:49 masarati Exp $ */
+/* $Header: /var/cvs/mbdyn/mbdyn/mbdyn-1.0/mbdyn/base/invsolver.cc,v 1.58 2017/09/09 09:20:12 masarati Exp $ */
 /*
  * MBDyn (C) is a multibody analysis code.
  * http://www.mbdyn.org
  *
- * Copyright (C) 1996-2015
+ * Copyright (C) 1996-2017
  *
  * Pierangelo Masarati	<masarati@aero.polimi.it>
  * Paolo Mantegazza	<mantegazza@aero.polimi.it>
@@ -30,7 +30,7 @@
  */
 
 /*
- * Copyright 1999-2015 Giuseppe Quaranta <quaranta@aero.polimi.it>
+ * Copyright 1999-2017 Giuseppe Quaranta <quaranta@aero.polimi.it>
  * Dipartimento di Ingegneria Aerospaziale - Politecnico di Milano
  *
  * This copyright statement applies to the MPI related code, which was
@@ -79,10 +79,12 @@
 InverseSolver::InverseSolver(MBDynParser& HPar,
 		const std::string& sInFName,
 		const std::string& sOutFName,
+		unsigned int nThreads,
 		bool bPar)
-: Solver(HPar, sInFName, sOutFName, bPar),
+: Solver(HPar, sInFName, sOutFName, nThreads, bPar),
 ProblemType(InverseDynamics::FULLY_ACTUATED_COLLOCATED),
-pXPrimePrime(0), pLambda(0)
+pXPrimePrime(0), pLambda(0),
+bFullResTest(false)
 {
 	DEBUGCOUTFNAME("InverseSolver::InverseSolver");
 }
@@ -114,9 +116,9 @@ InverseSolver::Prepare(void)
 		pRTSolver->Setup();
 	}
 
-#ifdef USE_SCHUR
 	int mpi_finalize = 0;
 
+#ifdef USE_SCHUR
 	if (bParallel) {
 		DEBUGLCOUT(MYDEBUG_MEM, "creating parallel SchurDataManager"
 				<< std::endl);
@@ -245,9 +247,6 @@ InverseSolver::Prepare(void)
 
 	/* relink those known drive callers that might need
 	 * the data manager, but were verated ahead of it */
-	if (pStrategyChangeDrive) {
-		pStrategyChangeDrive->SetDrvHdl(pDM->pGetDrvHdl());
-	}
 
 	ASSERT(iNumDofs > 0);
 
@@ -298,6 +297,10 @@ InverseSolver::Prepare(void)
 	pXPrimePrime->Reset();
 	pLambda->Reset();
 
+	/* relink those known drive callers that might need
+	 * the data manager, but were verated ahead of it */
+	pTSC->SetDriveHandler(pDM->pGetDrvHdl());
+
 	/*
 	 * Immediately link DataManager to current solution
 	 *
@@ -394,7 +397,7 @@ InverseSolver::Prepare(void)
 		{
 			NonlinearSolverTestRange *pRT = new NonlinearSolverTestRange(pResTest);
 			NonlinearSolverTestRange *pST = new NonlinearSolverTestRange(pSolTest);
-			pDM->IDSetTest(pRT, pST);
+			pDM->IDSetTest(pRT, pST, bFullResTest);
 			pResTest = pRT;
 			pSolTest = pST;
 		} break;
@@ -493,9 +496,10 @@ InverseSolver::Prepare(void)
 	outputCounterPrefix = bOutputCounter ? "\n" : "";
 	outputCounterPostfix = outputStep() ? "\n" : "\r";
 
-	ASSERT(pRegularSteps != NULL);
+	pTSC->Init(iMaxIterations, dMinTimeStep, MaxTimeStep, dInitialTimeStep);
 
 	/* Setup SolutionManager(s) */
+	ASSERT(pRegularSteps != 0);
 	SetupSolmans(pRegularSteps->GetIntegratorNumUnknownStates(), true);
 
 	/* this is here to force AfterConvergence()
@@ -625,9 +629,7 @@ IfStepIsToBeRepeated:
 			/* Riduce il passo */
 			CurrStep = StepIntegrator::REPEATSTEP;
 			doublereal dOldCurrTimeStep = dCurrTimeStep;
-			dCurrTimeStep = NewTimeStep(dCurrTimeStep,
-					iStIter,
-					CurrStep);
+			dCurrTimeStep = pTSC->dGetNewStepTime(CurrStep, iStIter); 
 			if (dCurrTimeStep < dOldCurrTimeStep) {
 				DEBUGCOUT("Changing time step"
 					" during step "
@@ -747,7 +749,7 @@ IfStepIsToBeRepeated:
 	bSolConv = false;
 
 	/* Calcola il nuovo timestep */
-	dCurrTimeStep = NewTimeStep(dCurrTimeStep, iStIter, CurrStep);
+	dCurrTimeStep = pTSC->dGetNewStepTime(CurrStep,iStIter);
 	DEBUGCOUT("Current time step: " << dCurrTimeStep << std::endl);
 
 	return true;
@@ -937,6 +939,7 @@ InverseSolver::ReadData(MBDynParser& HP)
 		"tolerance",
 		"max" "iterations",
 		"modify" "residual" "test",
+		"full" "residual" "test",
 
 		"abort" "after",
 			"input",
@@ -967,10 +970,6 @@ InverseSolver::ReadData(MBDynParser& HP)
 		/* END OF DEPRECATED */
 
 		"strategy",
-			"factor",
-			"no" "change",
-			"change",
-
 
 		/* DEPRECATED */
 		"solver",
@@ -1022,6 +1021,7 @@ InverseSolver::ReadData(MBDynParser& HP)
 		TOLERANCE,
 		MAXITERATIONS,
 		MODIFY_RES_TEST,
+		FULL_RES_TEST,
 
 		ABORTAFTER,
 		INPUT,
@@ -1050,9 +1050,6 @@ InverseSolver::ReadData(MBDynParser& HP)
 		/* END OF DEPRECATED */
 
 		STRATEGY,
-		STRATEGYFACTOR,
-		STRATEGYNOCHANGE,
-		STRATEGYCHANGE,
 
 		/* DEPRECATED */
 		SOLVER,
@@ -1110,8 +1107,8 @@ InverseSolver::ReadData(MBDynParser& HP)
 
 	doublereal dTol = ::dDefaultTol;
 	doublereal dSolutionTol = 0.;
-	integer iMaxIterations = ::iDefaultMaxIterations;
-	bool bModResTest = false;
+	iMaxIterations = ::iDefaultMaxIterations;
+	bool bModResTest(false);
 
 #ifdef USE_MULTITHREAD
 	bool bSolverThreads(false);
@@ -1439,8 +1436,17 @@ InverseSolver::ReadData(MBDynParser& HP)
 			}
 			break;
 
+		case FULL_RES_TEST:
+			if (HP.IsArg()) {
+				bFullResTest = HP.GetYesNoOrBool();
 
+			} else {
+				bFullResTest = true;
+			}
 
+			DEBUGLCOUT(MYDEBUG_INPUT,
+				"Full residual test: " << bFullResTest << std::endl);
+			break;
 
 		case NEWTONRAPHSON: {
 			pedantic_cout("Newton Raphson is deprecated; use "
@@ -1486,132 +1492,10 @@ InverseSolver::ReadData(MBDynParser& HP)
 			}
 			goto EndOfCycle;
 
-		case STRATEGY: {
-			switch (KeyWords(HP.GetWord())) {
-			case STRATEGYFACTOR: {
-				CurrStrategy = FACTOR;
-
-				/*
-				 * strategy: factor ,
-				 *     <reduction factor> ,
-				 *     <steps before reduction> ,
-				 *     <raise factor> ,
-				 *     <steps before raise> ,
-				 *     <min iterations> ,
-				 *     <max iterations> ;
-				 */
-
-				StrategyFactor.dReductionFactor = HP.GetReal();
-				if (StrategyFactor.dReductionFactor >= 1.) {
-					silent_cerr("warning, "
-						"illegal reduction factor "
-						"at line " << HP.GetLineData()
-						<< "; default value 1. "
-						"(no reduction) will be used"
-						<< std::endl);
-					StrategyFactor.dReductionFactor = 1.;
-				}
-
-				StrategyFactor.iStepsBeforeReduction = HP.GetInt();
-				if (StrategyFactor.iStepsBeforeReduction <= 0) {
-					silent_cerr("warning, "
-						"illegal number of steps "
-						"before reduction at line "
-						<< HP.GetLineData()
-						<< "; default value 1 will be "
-						"used (it may be dangerous)"
-						<< std::endl);
-					StrategyFactor.iStepsBeforeReduction = 1;
-				}
-
-				StrategyFactor.dRaiseFactor = HP.GetReal();
-				if (StrategyFactor.dRaiseFactor <= 1.) {
-					silent_cerr("warning, "
-						"illegal raise factor at line "
-						<< HP.GetLineData()
-						<< "; default value 1. "
-						"(no raise) will be used"
-						<< std::endl);
-					StrategyFactor.dRaiseFactor = 1.;
-				}
-
-				StrategyFactor.iStepsBeforeRaise = HP.GetInt();
-				if (StrategyFactor.iStepsBeforeRaise <= 0) {
-					silent_cerr("warning, "
-						"illegal number of steps "
-						"before raise at line "
-						<< HP.GetLineData()
-						<< "; default value 1 will be "
-						"used (it may be dangerous)"
-						<< std::endl);
-					StrategyFactor.iStepsBeforeRaise = 1;
-				}
-
-				StrategyFactor.iMinIters = HP.GetInt();
-				if (StrategyFactor.iMinIters <= 0) {
-					silent_cerr("warning, "
-						"illegal minimum number "
-						"of iterations at line "
-						<< HP.GetLineData()
-						<< "; default value 0 will be "
-						"used (never raise)"
-						<< std::endl);
-					StrategyFactor.iMinIters = 1;
-				}
-
-				StrategyFactor.iMaxIters = 0;
-				if (HP.IsArg()) {
-					StrategyFactor.iMaxIters = HP.GetInt();
-					if (StrategyFactor.iMaxIters <= 0) {
-						silent_cerr("warning, "
-							"illegal mmaximim number "
-							"of iterations at line "
-							<< HP.GetLineData()
-							<< "; default value will be "
-							"used"
-							<< std::endl);
-						StrategyFactor.iMaxIters = 0;
-					}
-				}
-
-				DEBUGLCOUT(MYDEBUG_INPUT,
-						"Time step control strategy: "
-						"Factor" << std::endl
-						<< "Reduction factor: "
-						<< StrategyFactor.dReductionFactor
-						<< "Steps before reduction: "
-						<< StrategyFactor.iStepsBeforeReduction
-						<< "Raise factor: "
-						<< StrategyFactor.dRaiseFactor
-						<< "Steps before raise: "
-						<< StrategyFactor.iStepsBeforeRaise
-						<< "Min iterations: "
-						<< StrategyFactor.iMinIters
-						<< "Max iterations: "
-						<< StrategyFactor.iMaxIters
-						<< std::endl);
-				break;
-			}
-
-			case STRATEGYNOCHANGE: {
-				CurrStrategy = NOCHANGE;
-				break;
-			}
-
-			case STRATEGYCHANGE: {
-				CurrStrategy = CHANGE;
-				pStrategyChangeDrive = HP.GetDriveCaller(true);
-				break;
-			}
-
-			default:
-				silent_cerr("unknown time step control "
-					"strategy at line "
-					<< HP.GetLineData() << std::endl);
-				throw ErrGeneric(MBDYN_EXCEPT_ARGS);
-			}
+		case STRATEGY:
+			pTSC = ReadTimeStepData(this,HP);
+			
 			break;
-		}
 
 		case SOLVER:
 			silent_cerr("\"solver\" keyword at line "
@@ -1948,27 +1832,21 @@ InverseSolver::ReadData(MBDynParser& HP)
 
 EndOfCycle: /* esce dal ciclo di lettura */
 
-	switch (CurrStrategy) {
-	case FACTOR:
-		if (StrategyFactor.iMaxIters <= StrategyFactor.iMinIters) {
-			silent_cerr("warning, "
-				<< "strategy maximum number "
-				<< "of iterations "
-				<< "is <= minimum: "
-				<< StrategyFactor.iMaxIters << " <= "
-				<< StrategyFactor.iMinIters << "; "
-				<< "the maximum global iteration value "
-				<< iMaxIterations << " "
-				<< "will be used"
-				<< std::endl);
-			StrategyFactor.iMaxIters = iMaxIterations;
-		}
-		break;
-
-	default:
-		break;
+	if (MaxTimeStep.pGetDriveCaller() == 0) {
+		DriveCaller *pDC = 0;
+		SAFENEWWITHCONSTRUCTOR(pDC, ConstDriveCaller, ConstDriveCaller(::dDefaultMaxTimeStep));
+		MaxTimeStep.Set(pDC);
+	}
+	
+	if (typeid(*MaxTimeStep.pGetDriveCaller()) == typeid(ConstDriveCaller)) {
+		MaxTimeStep.Set(new ConstDriveCaller(dInitialTimeStep));
 	}
 
+	if (pTSC == 0) {
+		pedantic_cout("No time step control strategy defined; defaulting to NoChange time step control" );
+		pTSC = new NoChange(this);
+	}
+	
 	if (dFinalTime < dInitialTime) {
 		eAbortAfter = AFTER_ASSEMBLY;
 	}
