@@ -1,9 +1,9 @@
-/* $Header: /var/cvs/mbdyn/mbdyn/mbdyn-1.0/mbdyn/base/linesearch.cc,v 1.14 2015/06/25 18:36:36 masarati Exp $ */
+/* $Header: /var/cvs/mbdyn/mbdyn/mbdyn-1.0/mbdyn/base/linesearch.cc,v 1.18 2017/01/12 14:46:09 masarati Exp $ */
 /* 
  * MBDyn (C) is a multibody analysis code. 
  * http://www.mbdyn.org
  *
- * Copyright (C) 1996-2015
+ * Copyright (C) 1996-2017
  *
  * Pierangelo Masarati	<masarati@aero.polimi.it>
  * Paolo Mantegazza	<mantegazza@aero.polimi.it>
@@ -30,7 +30,7 @@
  */
  
  /* 
-  * Portions Copyright (C) 2003-2015
+  * Portions Copyright (C) 2003-2017
   * Giuseppe Quaranta	<quaranta@aero.polimi.it>
   *
   * classi che implementano la risoluzione del sistema nonlineare 
@@ -38,7 +38,7 @@
 
  /*
  AUTHOR: Reinhard Resch <r.resch@secop.com>
-        Copyright (C) 2011(-2015) all rights reserved.
+        Copyright (C) 2011(-2017) all rights reserved.
 
         The copyright of this code is transferred
         to Pierangelo Masarati and Paolo Mantegazza
@@ -49,7 +49,7 @@
 #include "mbconfig.h"           /* This goes first in every *.c,*.cc file */
 
 #include <unistd.h>
-
+#include "clock_time.h"
 #include "solver.h"
 #include "linesearch.h"
 #ifdef USE_MPI
@@ -142,7 +142,7 @@ LineSearchSolver::Residual(doublereal& f, integer iIterCnt)
 #ifdef USE_EXTERNAL
 	SendExternal();
 #endif /* USE_EXTERNAL */
-
+        
 	pRes->Reset();
 
 	try {
@@ -278,7 +278,8 @@ LineSearchSolver::LineSearch(doublereal stpmax, doublereal fold,
 
 	doublereal lambda = 1.;
 	doublereal tmplam;
-	doublereal lambda2, f2;
+	doublereal lambda2 = 0; //f2, lambda2 initialized to silence g++ possible uninitialized warning
+	doublereal f2 = 0.;
 
 #ifdef DEBUG
 	lambda2 = f2 = NAN;
@@ -460,24 +461,58 @@ LineSearchSolver::Solve(const NonlinearProblem *pNonLinProblem,
 		: std::numeric_limits<doublereal>::max();
 
 	TRACE_VAR(stpmax);
-    
+
+	doublereal dStartTimeCPU, dEndTimeCPU, dJacobianCPU, dResidualCPU, dLinSolveCPU;
+        
 	while (true) {
+		if (outputCPUTime()) {
+			dStartTimeCPU = mbdyn_clock_time();
+		}
+
 		Jacobian();
+
 		ASSERT(pSM->pMatHdl()->iGetNumCols() == Size);
 		ASSERT(pSM->pMatHdl()->iGetNumCols() == pRes->iGetSize());
 		ASSERT(pSM->pMatHdl()->iGetNumRows() == pRes->iGetSize());
+
 		g.Reset();
 		pSM->pMatHdl()->MatTVecDecMul(g, *pRes); // compute gradient g = \nabla f = fjac^T \, fvec = -Jac^T \, pRes
+
+		if (outputCPUTime()) {
+			dEndTimeCPU = mbdyn_clock_time();
+			dJacobianCPU = dEndTimeCPU - dStartTimeCPU;
+			AddTimeCPU(dJacobianCPU, CPU_JACOBIAN);
+			dStartTimeCPU = dEndTimeCPU;
+		}
+
 		const doublereal fold = f;
+
 		pSM->Solve();
 
+		if (outputCPUTime()) {
+			dEndTimeCPU = mbdyn_clock_time();
+			dLinSolveCPU = dEndTimeCPU - dStartTimeCPU;
+			AddTimeCPU(dLinSolveCPU, CPU_LINEAR_SOLVER);
+		}
+
    		if (outputSol()) {
 			pS->PrintSolution(*pSol, iIterCnt);
 		}
-	
+
+		if (outputCPUTime()) {
+			dStartTimeCPU = mbdyn_clock_time();
+		}
+
 		LineSearch(stpmax, fold, f, check, iIterCnt);
+
 		bTest = MakeResTest(pS, pNLP, *pRes, Tol, dErr, dErrDiff);
 
+		if (outputCPUTime()) {
+			dEndTimeCPU = mbdyn_clock_time();
+			dResidualCPU = dEndTimeCPU - dStartTimeCPU;
+			AddTimeCPU(dResidualCPU, CPU_RESIDUAL);
+		}
+
 		if (iIterCnt > 0) {
 			dErrFactor *= dErr / dPrevErr;
 		}
@@ -507,6 +542,12 @@ LineSearchSolver::Solve(const NonlinearProblem *pNonLinProblem,
 					}
 				}
 
+				if (outputCPUTime()) {
+					silent_cout(" CPU:" << dResidualCPU << "/" << dGetTimeCPU(CPU_RESIDUAL)
+						<< "+" << dJacobianCPU << "/" << dGetTimeCPU(CPU_JACOBIAN)
+						<< "+" << dLinSolveCPU << "/" << dGetTimeCPU(CPU_LINEAR_SOLVER));
+				}
+
 				if (uFlags & PRINT_CONVERGENCE_INFO) {
 					silent_cout(" f=" << std::setw(12) << f);
 
