@@ -1,9 +1,9 @@
-/* $Header: /var/cvs/mbdyn/mbdyn/mbdyn-1.0/mbdyn/base/mbpar.cc,v 1.112 2015/06/25 18:36:36 masarati Exp $ */
+/* $Header: /var/cvs/mbdyn/mbdyn/mbdyn-1.0/mbdyn/base/mbpar.cc,v 1.114 2017/08/28 10:34:39 masarati Exp $ */
 /* 
  * MBDyn (C) is a multibody analysis code. 
  * http://www.mbdyn.org
  *
- * Copyright (C) 1996-2015
+ * Copyright (C) 1996-2017
  *
  * Pierangelo Masarati	<masarati@aero.polimi.it>
  * Paolo Mantegazza	<mantegazza@aero.polimi.it>
@@ -54,6 +54,9 @@
 #include "modules.h"
 
 #include "legalese.h"
+#include "streamoutelem.h"
+#include "socketstreamdrive.h"
+#include "drive_.h"
 
 struct RefFrameDR : public DescRead {
 	bool Read(HighParser& HP);
@@ -220,17 +223,21 @@ pDM(0)
 	InitTplDC();
 	InitCL();
 	InitSF();
+	InitStreamOutputContentTypes();
 
 	// NOTE: data will be destroyed when the underlying HighParser is destroyed (is this what we want?)
 	InitDescData();
-}   
+}
 
 MBDynParser::~MBDynParser(void)
-{   
+{
 	DestroyDriveCallerData();
 	DestroyTplDC();
 	DestroyCL();
 	DestroySF();
+	DestroyStreamOutputContentTypes();
+	DestroyFileDriveContentTypes();
+	DestroyFileDriveCallerTypes();
 
 	for (SFType::iterator i = SF.begin(); i != SF.end(); ++i) {
 		SAFEDELETE(i->second);
