@@ -1,9 +1,9 @@
-/* $Header: /var/cvs/mbdyn/mbdyn/mbdyn-1.0/mbdyn/base/output.cc,v 1.64 2016/02/17 15:40:04 masarati Exp $ */
+/* $Header: /var/cvs/mbdyn/mbdyn/mbdyn-1.0/mbdyn/base/output.cc,v 1.74 2017/05/29 18:10:33 masarati Exp $ */
 /*
  * MBDyn (C) is a multibody analysis code.
  * http://www.mbdyn.org
  *
- * Copyright (C) 1996-2015
+ * Copyright (C) 1996-2017
  *
  * Pierangelo Masarati	<masarati@aero.polimi.it>
  * Paolo Mantegazza	<mantegazza@aero.polimi.it>
@@ -33,6 +33,8 @@
 
 #include "mbconfig.h"           /* This goes first in every *.c,*.cc file */
 
+#include <sstream>
+
 #include "output.h"
 
 /* OutputHandler - begin */
@@ -62,24 +64,23 @@ const char* psExt[] = {
 	".usr",
 	".gen",		// 15
 	".par",
-	".res",
-	".ada",
 	".amd",
-	".rfm",		// 20
+	".rfm",
 	".log",
-	".air",
+	".air",		// 20
 	".prm",
 	".ext",
-	".mod",		// 25
+	".mod",
 	".nc",
-	".thn",
+	".thn",		// 25
 	".the",
 	".pla",
-	".grv",		// 30
+	".grv",
 	".dof",
-	".drv",
+	".drv",		// 30
 	".trc",
-	NULL		// 34
+	".m",		// NOTE: ALWAYS LAST!
+	NULL		// 33
 };
 
 /* Costruttore senza inizializzazione */
@@ -202,14 +203,6 @@ OutputHandler::OutputHandler_int(void)
 		| OUTPUT_MAY_USE_TEXT | OUTPUT_USE_TEXT;
 	OutData[PARTITION].pof = &ofPartition;
 
-	OutData[ADAMSRES].flags = OUTPUT_USE_DEFAULT_PRECISION | OUTPUT_USE_SCIENTIFIC
-		| OUTPUT_MAY_USE_TEXT | OUTPUT_USE_TEXT;
-	OutData[ADAMSRES].pof = &ofAdamsRes;
-
-	OutData[ADAMSCMD].flags = OUTPUT_USE_DEFAULT_PRECISION | OUTPUT_USE_SCIENTIFIC
-		| OUTPUT_MAY_USE_TEXT | OUTPUT_USE_TEXT;
-	OutData[ADAMSCMD].pof = &ofAdamsCmd;
-
 	OutData[AEROMODALS].flags = OUTPUT_USE_DEFAULT_PRECISION | OUTPUT_USE_SCIENTIFIC
 		| OUTPUT_MAY_USE_TEXT | OUTPUT_USE_TEXT;
 	OutData[AEROMODALS].pof = &ofAeroModals;
@@ -258,6 +251,10 @@ OutputHandler::OutputHandler_int(void)
 			| OUTPUT_MAY_USE_TEXT | OUTPUT_USE_TEXT;
 	OutData[TRACES].pof = &ofTraces;
 
+	OutData[EIGENANALYSIS].flags = OUTPUT_USE_DEFAULT_PRECISION | OUTPUT_USE_SCIENTIFIC
+			| OUTPUT_MAY_USE_TEXT | OUTPUT_USE_TEXT;
+	OutData[EIGENANALYSIS].pof = &ofEigenanalysis;
+
 	OutData[NETCDF].flags = 0
 		| OUTPUT_MAY_USE_NETCDF;
 	OutData[NETCDF].pof = 0;
@@ -282,7 +279,9 @@ OutputHandler::~OutputHandler(void)
 		if (IsOpen(iCnt)) {
 #ifdef USE_NETCDF
 			if (iCnt == NETCDF) {
-				delete m_pBinFile;
+				if (m_pBinFile != 0) {
+					delete m_pBinFile;
+				}
 
 			} else
 #endif /* USE_NETCDF */
@@ -298,25 +297,25 @@ OutputHandler::~OutputHandler(void)
 bool
 OutputHandler::Open(const OutputHandler::OutFiles out)
 {
-	if (!IsOpen(out)) {
 #ifdef USE_NETCDF
-		if (out == NETCDF) {
-			m_pBinFile = new NcFile(_sPutExt((char*)(psExt[NETCDF])), NcFile::Replace);
-			m_pBinFile->set_fill(NcFile::Fill);
-	
-         		if (!m_pBinFile->is_valid()) {
-				silent_cerr("NetCDF file is invalid" << std::endl);
-				throw ErrFile(MBDYN_EXCEPT_ARGS);
-			}
+	if (out == NETCDF && !IsOpen(out)) {
+		m_pBinFile = new NcFile(_sPutExt((char*)(psExt[NETCDF])), NcFile::Replace);
+		m_pBinFile->set_fill(NcFile::Fill);
 
-			// Let's define some dimensions which could be useful	       	     
-			m_DimTime = CreateDim("time");
-			m_DimV1 = CreateDim("vec1", 1);
-			m_DimV3 = CreateDim("vec3", 3);
+         	if (!m_pBinFile->is_valid()) {
+			silent_cerr("NetCDF file is invalid" << std::endl);
+			throw ErrFile(MBDYN_EXCEPT_ARGS);
+		}
 
-		} else
+		// Let's define some dimensions which could be useful
+		m_DimTime = CreateDim("time");
+		m_DimV1 = CreateDim("vec1", 1);
+		m_DimV3 = CreateDim("vec3", 3);
+
+	} else
 #endif /* USE_NETCDF */
-		{
+	{
+		if (!IsOpen(out)) {
 			const char *fname = _sPutExt(psExt[out]);
 
 			// Apre lo stream
@@ -327,18 +326,63 @@ OutputHandler::Open(const OutputHandler::OutFiles out)
 					"\"" << fname << "\"" << std::endl);
 				throw ErrFile(MBDYN_EXCEPT_ARGS);
 			}
+
+			if (UseText(out)) {
+				// Setta la formattazione dei campi
+				if (UseDefaultPrecision(out)) {
+					OutData[out].pof->precision(iCurrPrecision);
+				}
+
+				// Setta la notazione
+				if (UseScientific(out)) {
+					OutData[out].pof->setf(std::ios::scientific);
+				}
+			}
 		}
 
-		if (UseText(out)) {
-			// Setta la formattazione dei campi
-			if (UseDefaultPrecision(out)) {
-				OutData[out].pof->precision(iCurrPrecision);
-			}
+		return true;
+	}
 
-			// Setta la notazione
-			if (UseScientific(out)) {
-				OutData[out].pof->setf(std::ios::scientific);
-			}
+	return false;
+}
+
+bool
+OutputHandler::Open(const int out, const std::string& postfix)
+{
+	if (UseText(out) && !IsOpen(out)) {
+		std::string sCurrFileName = sGet();
+		std::stringstream fname_ss;
+
+		unsigned uExtIdx = sCurrFileName.find_last_of(EXT_SEP);
+
+		if (uExtIdx != std::string::npos) {
+			fname_ss << sCurrFileName.substr(0, uExtIdx);
+
+		} else {
+			fname_ss << sCurrFileName;
+		}
+		
+		fname_ss << postfix << psExt[out] << std::ends;
+
+		const std::string fname = fname_ss.str();
+
+		// Opens the stream
+		OutData[out].pof->open(fname.c_str());
+
+		if (!(*OutData[out].pof)) {
+			silent_cerr("Unable to open file "
+				"\"" << fname << "\"" << std::endl);
+			throw ErrFile(MBDYN_EXCEPT_ARGS);
+		}
+
+		// Sets the field format
+		if (UseDefaultPrecision(out)) {
+			OutData[out].pof->precision(iCurrPrecision);
+		}
+
+		// Sets the notation
+		if (UseScientific(out)) {
+			OutData[out].pof->setf(std::ios::scientific);
 		}
 
 		return true;
@@ -589,20 +633,6 @@ OutputHandler::PartitionOpen(void)
 	return Open(PARTITION);
 }
 
-bool
-OutputHandler::AdamsResOpen(void)
-{
-	ASSERT(!IsOpen(ADAMSRES));
-	return Open(ADAMSRES);
-}
-
-bool
-OutputHandler::AdamsCmdOpen(void)
-{
-	ASSERT(!IsOpen(ADAMSCMD));
-	return Open(ADAMSCMD);
-}
-
 bool
 OutputHandler::LogOpen(void)
 {
@@ -859,12 +889,14 @@ ToBeOutput::fToBeOutput(void) const
 bool
 ToBeOutput::bToBeOutput(void) const
 {
-  	return (fOutput & flag(1));
+	return fOutput & flag(1);
 }
 
 void
 ToBeOutput::SetOutputFlag(flag f)
 {
+	ASSERT(f ? f & flag(1) : 1);
+
   	fOutput = f;
 }
 
@@ -886,6 +918,8 @@ flag Traceable::fToBeTraced(void) const
 
 void Traceable::SetTraceFlag(flag f)
 {
+	ASSERT(f ? f & flag(1) : 1);
+
 	fTrace = f;
 }
 
