@@ -1,9 +1,9 @@
-/* $Header: /var/cvs/mbdyn/mbdyn/mbdyn-1.0/mbdyn/base/output.h,v 1.61 2016/02/17 15:40:04 masarati Exp $ */
+/* $Header: /var/cvs/mbdyn/mbdyn/mbdyn-1.0/mbdyn/base/output.h,v 1.65 2017/05/29 17:50:43 masarati Exp $ */
 /*
  * MBDyn (C) is a multibody analysis code.
  * http://www.mbdyn.org
  *
- * Copyright (C) 1996-2015
+ * Copyright (C) 1996-2017
  *
  * Pierangelo Masarati	<masarati@aero.polimi.it>
  * Paolo Mantegazza	<mantegazza@aero.polimi.it>
@@ -49,9 +49,9 @@
 
 #ifdef USE_NETCDF
 #if defined(HAVE_NETCDFCPP_H)
-#include <netcdfcpp.h>  
+#include <netcdfcpp.h>
 #elif defined(HAVE_NETCDF_H)
-#include <netcdf.h>  
+#include <netcdf.h>
 #endif
 #endif /* USE_NETCDF */
 
@@ -84,24 +84,23 @@ public:
 		LOADABLE,
 		GENELS,				// 15
 		PARTITION,
-		ADAMSRES,
-		ADAMSCMD,
 		AEROMODALS,
-		REFERENCEFRAMES,		// 20
+		REFERENCEFRAMES,
 		LOG,
-		AIRPROPS,
+		AIRPROPS,			// 20
 		PARAMETERS,
 		EXTERNALS,
-		MODAL,				// 25
+		MODAL,
 		NETCDF,
-		THERMALNODES,
+		THERMALNODES,			// 25
 		THERMALELEMENTS,
 		PLATES,
-		GRAVITY,			// 30
+		GRAVITY,
 		DOFSTATS,
-		DRIVECALLERS,
+		DRIVECALLERS,			// 30
 		TRACES,
-		LASTFILE			// 34
+		EIGENANALYSIS,			// NOTE: ALWAYS LAST!
+		LASTFILE			// 33
 	};
 
 private:
@@ -139,7 +138,7 @@ private:
 		std::ofstream*	pof;
 		unsigned	flags;
 	} OutData[LASTFILE];
-		
+
 	// NetCDF dimensions and global attributes related to the binary file
 #ifdef USE_NETCDF
 	const NcDim *m_DimTime;
@@ -166,22 +165,21 @@ private:
 	std::ofstream ofLoadable;
 	std::ofstream ofGenels;			/* 15 */
 	std::ofstream ofPartition;
-	std::ofstream ofAdamsRes;
-	std::ofstream ofAdamsCmd;
 	std::ofstream ofAeroModals;
 	std::ofstream ofReferenceFrames;	/* 20 */
 	std::ofstream ofLog;
 	std::ofstream ofAirProps;
 	std::ofstream ofParameters;
 	std::ofstream ofExternals;
-	std::ofstream ofModal;
+	std::ofstream ofModal;			/* 25 */
 	std::ofstream ofThermalNodes;
 	std::ofstream ofThermalElements;
 	std::ofstream ofPlates;
 	std::ofstream ofGravity;
-	std::ofstream ofDofStats;
+	std::ofstream ofDofStats;		/* 30 */
 	std::ofstream ofDriveCallers;
 	std::ofstream ofTraces;
+	std::ofstream ofEigenanalysis;
 
 	int iCurrWidth;
 	int iCurrPrecision;
@@ -210,6 +208,8 @@ public:
 	/* Aggiungere qui le funzioni che aprono i singoli stream */
 	bool Open(const OutputHandler::OutFiles out);
 
+	/* Overload for eigenanalysis text output */
+	bool Open(const int out, const std::string& postfix);
 	bool IsOpen(const OutputHandler::OutFiles out) const;
 	bool UseDefaultPrecision(const OutputHandler::OutFiles out) const;
 	bool UseScientific(const OutputHandler::OutFiles out) const;
@@ -230,8 +230,6 @@ public:
 	bool RestartOpen(bool openResXSol = false);
 
 	bool PartitionOpen(void);
-	bool AdamsResOpen(void);
-	bool AdamsCmdOpen(void);
 	bool LogOpen(void);
 
 	/* Aggiungere qui le funzioni che ritornano gli stream desiderati */
@@ -254,8 +252,6 @@ public:
 	inline std::ostream& Loadable(void) const;
 	inline std::ostream& Genels(void) const;
 	inline std::ostream& Partition(void) const;
-	inline std::ostream& AdamsRes(void) const;
-	inline std::ostream& AdamsCmd(void) const;
 	inline std::ostream& AeroModals(void) const;
 	inline std::ostream& ReferenceFrames(void) const;
 	inline std::ostream& Log(void) const;
@@ -270,6 +266,7 @@ public:
 	inline std::ostream& DofStats(void) const;
 	inline std::ostream& DriveCallers(void) const;
 	inline std::ostream& Traces(void) const;
+	inline std::ostream& Eigenanalysis(void) const;
 
 	inline int iW(void) const;
 	inline int iP(void) const;
@@ -526,20 +523,6 @@ OutputHandler::Partition(void) const
 	return const_cast<std::ostream &>(dynamic_cast<const std::ostream &>(ofPartition));
 }
 
-inline std::ostream&
-OutputHandler::AdamsRes(void) const
-{
-	ASSERT(IsOpen(ADAMSRES));
-	return const_cast<std::ostream &>(dynamic_cast<const std::ostream &>(ofAdamsRes));
-}
-
-inline std::ostream&
-OutputHandler::AdamsCmd(void) const
-{
-	ASSERT(IsOpen(ADAMSCMD));
-	return const_cast<std::ostream &>(dynamic_cast<const std::ostream &>(ofAdamsCmd));
-}
-
 inline std::ostream&
 OutputHandler::AeroModals(void) const
 {
@@ -628,6 +611,14 @@ OutputHandler::Traces(void) const
 	return const_cast<std::ostream &>(dynamic_cast<const std::ostream &>(ofTraces));
 }
 
+inline std::ostream&
+OutputHandler::Eigenanalysis(void) const
+{
+	ASSERT(IsOpen(EIGENANALYSIS));
+	return const_cast<std::ostream &>(dynamic_cast<const std::ostream &>(ofEigenanalysis));
+}
+
+
 inline int
 OutputHandler::iW(void) const
 {
@@ -707,4 +698,3 @@ private:
 };
 
 #endif /* OUTPUT_H */
-
