@@ -1,9 +1,9 @@
-/* $Header: /var/cvs/mbdyn/mbdyn/mbdyn-1.0/mbdyn/base/stepsol.h,v 1.49 2015/06/25 18:36:37 masarati Exp $ */
+/* $Header: /var/cvs/mbdyn/mbdyn/mbdyn-1.0/mbdyn/base/stepsol.h,v 1.51 2017/10/14 23:58:06 masarati Exp $ */
 /* 
  * MBDyn (C) is a multibody analysis code. 
  * http://www.mbdyn.org
  *
- * Copyright (C) 1996-2015
+ * Copyright (C) 1996-2017
  *
  * Pierangelo Masarati	<masarati@aero.polimi.it>
  * Paolo Mantegazza	<mantegazza@aero.polimi.it>
@@ -31,7 +31,7 @@
  
  /* 
   *
-  * Copyright (C) 2003-2015
+  * Copyright (C) 2003-2017
   * Giuseppe Quaranta	<quaranta@aero.polimi.it>
   *
   * Classe che gestisce l'integrazione di un passo temporale
@@ -185,6 +185,9 @@ class DerivativeSolver:
 	public ImplicitStepIntegrator{
 private:
 	doublereal dCoef;
+	const int iMaxIterCoef;
+	const doublereal dFactorCoef;
+
 protected:
 	void UpdateDof(const int DCount,
 		const DofOrder::Order Order,
@@ -194,7 +197,9 @@ public:
 			const doublereal dSolTl, 
 			const doublereal dC,
 			const integer iMaxIt,
-			const bool bmod_res_test);
+			const bool bmod_res_test,
+			const integer iMaxIterCoef,
+			const doublereal dFactorCoef);
 
 	~DerivativeSolver(void);
 	
