@@ -1,9 +1,9 @@
-/* $Header: /var/cvs/mbdyn/mbdyn/mbdyn-1.0/mbdyn/elec/genel.cc,v 1.60 2015/06/25 18:36:48 masarati Exp $ */
+/* $Header: /var/cvs/mbdyn/mbdyn/mbdyn-1.0/mbdyn/elec/genel.cc,v 1.62 2017/01/12 14:46:22 masarati Exp $ */
 /*
  * MBDyn (C) is a multibody analysis code.
  * http://www.mbdyn.org
  *
- * Copyright (C) 1996-2015
+ * Copyright (C) 1996-2017
  *
  * Pierangelo Masarati	<masarati@aero.polimi.it>
  * Paolo Mantegazza	<mantegazza@aero.polimi.it>
@@ -507,6 +507,16 @@ ReadGenel(DataManager* pDM,
 			throw DataManager::ErrGeneric(MBDYN_EXCEPT_ARGS);
 		}
 
+		doublereal X0 = 0.;
+
+		if (HP.IsKeyWord("position")) {
+			if (HP.IsKeyWord("from" "node")) {
+				X0 = SD.pNode->dGetX();
+			} else {
+				X0 = HP.GetReal();
+			}
+		}
+
 		flag fOut = pDM->fReadOutput(HP, Elem::GENEL);
 
 		switch (CLType) {
@@ -514,7 +524,7 @@ ReadGenel(DataManager* pDM,
 			SAFENEWWITHCONSTRUCTOR(pEl,
 				GenelSpringSupport,
 				GenelSpringSupport(uLabel, pDO, pCL,
-					SD, fOut));
+					SD, X0, fOut));
 			break;
 
 		case ConstLawType::VISCOUS:
@@ -522,7 +532,7 @@ ReadGenel(DataManager* pDM,
 			SAFENEWWITHCONSTRUCTOR(pEl,
 				GenelSpringDamperSupport,
 				GenelSpringDamperSupport(uLabel, pDO, pCL,
-					SD, fOut));
+					SD, X0, fOut));
 			break;
 
 		default:
