@@ -1,9 +1,9 @@
-/* $Header: /var/cvs/mbdyn/mbdyn/mbdyn-1.0/mbdyn/elec/genel_.cc,v 1.13 2016/02/17 15:40:14 masarati Exp $ */
+/* $Header: /var/cvs/mbdyn/mbdyn/mbdyn-1.0/mbdyn/elec/genel_.cc,v 1.15 2017/01/12 14:46:22 masarati Exp $ */
 /*
  * MBDyn (C) is a multibody analysis code.
  * http://www.mbdyn.org
  *
- * Copyright (C) 1996-2015
+ * Copyright (C) 1996-2017
  *
  * Pierangelo Masarati	<masarati@aero.polimi.it>
  * Paolo Mantegazza	<mantegazza@aero.polimi.it>
@@ -517,10 +517,10 @@ GenelSpring::GetConnectedNodes(std::vector<const Node *>& connectedNodes) const
 GenelSpringSupport::GenelSpringSupport(unsigned int uLabel,
 	const DofOwner* pDO,
 	const ConstitutiveLaw1D* pCL,
-	const ScalarDof& sd, flag fOutput)
+	const ScalarDof& sd, doublereal X0, flag fOutput)
 : Elem(uLabel, fOutput),
 Genel(uLabel, pDO, fOutput),
-ConstitutiveLaw1DOwner(pCL), SD(sd), dVal(0.)
+ConstitutiveLaw1DOwner(pCL), SD(sd), dVal(0.), dInitVal(X0)
 {
 	ASSERT(SD.iOrder == 0);
 }
@@ -600,7 +600,7 @@ GenelSpringSupport::AssRes(SubVectorHandler& WorkVec,
 
 	integer iNodeRowIndex = SD.pNode->iGetFirstRowIndex() + 1;
 
-	dVal = SD.pNode->dGetX();
+	dVal = SD.pNode->dGetX() - dInitVal;
 	ConstitutiveLaw1DOwner::Update(dVal, 0.);
 
 	WorkVec.PutItem(1, iNodeRowIndex, -GetF());
@@ -620,7 +620,7 @@ GenelSpringSupport::GetConnectedNodes(
 
 unsigned int GenelSpringSupport::iGetNumPrivData(void) const
 {
-	return 1u;
+	return 2u;
 }
 
 unsigned int GenelSpringSupport::iGetPrivDataIdx(const char *s) const
@@ -629,6 +629,10 @@ unsigned int GenelSpringSupport::iGetPrivDataIdx(const char *s) const
 		return 1u;
 	}
 
+	if (0 == strcmp(s, "X")) {
+		return 2u;
+	}
+
 	silent_cerr("genel(" << GetLabel() << "): private data \"" << s << "\" not available" << std::endl);
 	throw ErrGeneric(MBDYN_EXCEPT_ARGS);
 }
@@ -638,6 +642,8 @@ doublereal GenelSpringSupport::dGetPrivData(unsigned int i) const
 	switch (i) {
 	case 1u:
 		return GetF();
+	case 2u:
+		return dVal;
 	default:
 		silent_cerr("genel(" << GetLabel() << "): private data index " << i << " out of range" << std::endl);
 		throw ErrGeneric(MBDYN_EXCEPT_ARGS);
@@ -893,11 +899,11 @@ GenelCrossSpringDamperSupport::GetConnectedNodes(
 GenelSpringDamperSupport::GenelSpringDamperSupport(unsigned int uLabel,
 	const DofOwner* pDO,
 	const ConstitutiveLaw1D* pCL,
-	const ScalarDof& sd, flag fOutput)
+	const ScalarDof& sd, doublereal X0, flag fOutput)
 : Elem(uLabel, fOutput),
 Genel(uLabel, pDO, fOutput),
 ConstitutiveLaw1DOwner(pCL),
-SD(sd), dVal(0.),dValPrime(0.)
+SD(sd), dVal(0.), dInitVal(X0), dValPrime(0.)
 {
 	ASSERT(sd.pNode->GetDofType(0) == DofOrder::DIFFERENTIAL);
 	ASSERT(sd.iOrder == 0);
@@ -979,7 +985,7 @@ GenelSpringDamperSupport::AssRes(SubVectorHandler& WorkVec,
 
 	integer iNodeRowIndex = SD.pNode->iGetFirstRowIndex()+1;
 
-	dVal = SD.pNode->dGetX();
+	dVal = SD.pNode->dGetX() - dInitVal;
 	dValPrime = SD.pNode->dGetXPrime();
 
 	ConstitutiveLaw1DOwner::Update(dVal, dValPrime);
