@@ -1,9 +1,9 @@
-/* $Header: /var/cvs/mbdyn/mbdyn/mbdyn-1.0/mbdyn/struct/strext.cc,v 1.66 2016/02/17 15:40:35 masarati Exp $ */
+/* $Header: /var/cvs/mbdyn/mbdyn/mbdyn-1.0/mbdyn/struct/strext.cc,v 1.68 2017/07/31 14:19:54 masarati Exp $ */
 /* 
  * MBDyn (C) is a multibody analysis code. 
  * http://www.mbdyn.org
  *
- * Copyright (C) 2007-2015
+ * Copyright (C) 2007-2017
  *
  * Pierangelo Masarati	<masarati@aero.polimi.it>
  * Paolo Mantegazza	<mantegazza@aero.polimi.it>
@@ -370,7 +370,7 @@ StructExtForce::Prepare(ExtFileHandlerBase *pEFH)
 		if (uNodal != MBC_NODAL) {
 			silent_cerr("StructExtForce(" << GetLabel() << "): "
 				"negotiation response failed: expecting MBC_NODAL "
-				"(=" << MBC_MODAL << "), got " << uNodal
+				"(=" << MBC_NODAL << "), got " << uNodal
 				<< std::endl);
 			bResult = false;
 		}
