@@ -1,9 +1,9 @@
-/* $Header: /var/cvs/mbdyn/mbdyn/mbdyn-1.0/mbdyn/struct/strforce.cc,v 1.44 2016/02/17 15:40:35 masarati Exp $ */
+/* $Header: /var/cvs/mbdyn/mbdyn/mbdyn-1.0/mbdyn/struct/strforce.cc,v 1.47 2017/07/03 22:22:09 masarati Exp $ */
 /*
  * MBDyn (C) is a multibody analysis code.
  * http://www.mbdyn.org
  *
- * Copyright (C) 1996-2015
+ * Copyright (C) 1996-2017
  *
  * Pierangelo Masarati	<masarati@aero.polimi.it>
  * Paolo Mantegazza	<mantegazza@aero.polimi.it>
@@ -590,7 +590,7 @@ AbsoluteForce::OutputPrepare(OutputHandler& OH)
 			// joint sub-data
 			os << '.';
 			Var_F = OH.CreateVar<Vec3>(os.str() + "F", "N",
-				"force components (x, y, z)");
+				"global force components (x, y, z)");
 
 			Var_A = OH.CreateVar<Vec3>(os.str() + "Arm", "m",
 				"arm in global frame (x, y, z)");
@@ -878,9 +878,16 @@ FollowerForce::OutputPrepare(OutputHandler& OH)
 			(void)OH.CreateVar(os.str(), "follower");
 
 			// joint sub-data
-			os << '.';
-			Var_F = OH.CreateVar<Vec3>(os.str() + "F", "N",
-				"force components (x, y, z)");
+			if (fToBeOutput() & StructuralForce::OUTPUT_REL) {
+				os << '.';
+				Var_F = OH.CreateVar<Vec3>(os.str() + "f", "N",
+					"local force components (x, y, z)");
+
+			} else {
+				os << '.';
+				Var_F = OH.CreateVar<Vec3>(os.str() + "F", "N",
+					"global force components (x, y, z)");
+			}
 
 			Var_A = OH.CreateVar<Vec3>(os.str() + "Arm", "m",
 				"arm in global frame (x, y, z)");
@@ -895,7 +902,11 @@ FollowerForce::Output(OutputHandler& OH) const
 	if (bToBeOutput()) {
 #ifdef USE_NETCDF
 		if (OH.UseNetCDF(OutputHandler::FORCES)) {
-			Var_F->put_rec((pNode->GetRCurr()*f.Get()).pGetVec(), OH.GetCurrentStep());
+			if (fToBeOutput() & OUTPUT_REL) {
+				Var_F->put_rec((f.Get()).pGetVec(), OH.GetCurrentStep());
+			} else {
+				Var_F->put_rec((pNode->GetRCurr()*f.Get()).pGetVec(), OH.GetCurrentStep());
+			}
 			Var_A->put_rec((pNode->GetXCurr() + pNode->GetRCurr()*Arm).pGetVec(), OH.GetCurrentStep());
 		}
 #endif // USE_NETCDF
@@ -903,8 +914,18 @@ FollowerForce::Output(OutputHandler& OH) const
 		if (OH.UseText(OutputHandler::FORCES)) {
 			OH.Forces()
 				<< GetLabel()
-				<< " " << pNode->GetLabel()
-				<< " " << pNode->GetRCurr()*f.Get()
+				<< " " << pNode->GetLabel();
+
+			if (fToBeOutput() & OUTPUT_REL) {
+				OH.Forces()
+					<< " " << f.Get();
+
+			} else {
+				OH.Forces()
+					<< " " << pNode->GetRCurr()*f.Get();
+			}
+			
+			OH.Forces()
 				<< " " << pNode->GetXCurr() + pNode->GetRCurr()*Arm
 				<< std::endl;
 		}
@@ -1109,7 +1130,7 @@ AbsoluteCouple::OutputPrepare(OutputHandler& OH)
 			// joint sub-data
 			os << '.';
 			Var_F = OH.CreateVar<Vec3>(os.str() + "M", "Nm",
-				"couple components (x, y, z)");
+				"global couple components (x, y, z)");
 		}
 #endif // USE_NETCDF
 	}
@@ -1314,8 +1335,14 @@ FollowerCouple::OutputPrepare(OutputHandler& OH)
 			// joint sub-data
 			os << '.';
 
-			Var_F = OH.CreateVar<Vec3>(os.str() + "M", "Nm",
-				"couple components (x, y, z)");
+			if (fToBeOutput() & StructuralForce::OUTPUT_REL) {
+				Var_F = OH.CreateVar<Vec3>(os.str() + "m", "Nm",
+					"local couple components (x, y, z)");
+
+			} else {
+				Var_F = OH.CreateVar<Vec3>(os.str() + "M", "Nm",
+					"global couple components (x, y, z)");
+			}
 		}
 #endif // USE_NETCDF
 	}
@@ -1328,16 +1355,28 @@ FollowerCouple::Output(OutputHandler& OH) const
 	if (bToBeOutput()) {
 #ifdef USE_NETCDF
 		if (OH.UseNetCDF(OutputHandler::FORCES)) {
-			Var_F->put_rec((pNode->GetRCurr()*f.Get()).pGetVec(), OH.GetCurrentStep());
+			if (fToBeOutput() & OUTPUT_REL) {
+				Var_F->put_rec(f.Get().pGetVec(), OH.GetCurrentStep());
+			} else {
+				Var_F->put_rec((pNode->GetRCurr()*f.Get()).pGetVec(), OH.GetCurrentStep());
+			}
 		}
 #endif // USE_NETCDF
 
 		if (OH.UseText(OutputHandler::FORCES)) {
 			OH.Forces()
 				<< GetLabel()
-				<< " " << pNode->GetLabel()
-				<< " " << pNode->GetRCurr()*f.Get()
-				<< std::endl;
+				<< " " << pNode->GetLabel();
+			if (fToBeOutput() & OUTPUT_REL) {
+				OH.Forces()
+					<< " " << f.Get()
+					<< std::endl;
+
+			} else {
+				OH.Forces()
+					<< " " << pNode->GetRCurr()*f.Get()
+					<< std::endl;
+			}
 		}
 	}
 }
@@ -1643,7 +1682,7 @@ AbsoluteInternalForce::OutputPrepare(OutputHandler& OH)
 			// joint sub-data
 			os << '.';
 			Var_F = OH.CreateVar<Vec3>(os.str() + "F", "N",
-				"couple components (x, y, z)");
+				"global force components (x, y, z)");
 
 			Var_A1 = OH.CreateVar<Vec3>(os.str() + "Arm1", "m",
 				"node 1 arm in global frame (x, y, z)");
@@ -1997,8 +2036,13 @@ FollowerInternalForce::OutputPrepare(OutputHandler& OH)
 
 			// joint sub-data
 			os << '.';
-			Var_F = OH.CreateVar<Vec3>(os.str() + "F", "N",
-				"couple components (x, y, z)");
+			if (fToBeOutput() & StructuralForce::OUTPUT_REL) {
+				Var_F = OH.CreateVar<Vec3>(os.str() + "f", "N",
+					"local force components (x, y, z)");
+			} else {
+				Var_F = OH.CreateVar<Vec3>(os.str() + "F", "N",
+					"global force components (x, y, z)");
+			}
 
 			Var_A1 = OH.CreateVar<Vec3>(os.str() + "Arm1", "m",
 				"node 1 arm in global frame (x, y, z)");
@@ -2016,14 +2060,24 @@ FollowerInternalForce::Output(OutputHandler& OH) const
 	if (bToBeOutput()) {
 #ifdef USE_NETCDF
 		if (OH.UseNetCDF(OutputHandler::FORCES)) {
-			Var_F->put_rec((pNode1->GetRCurr()*f.Get()).pGetVec(), OH.GetCurrentStep());
+			if (fToBeOutput() & StructuralForce::OUTPUT_REL) {
+				Var_F->put_rec(f.Get().pGetVec(), OH.GetCurrentStep());
+			} else {
+				Var_F->put_rec((pNode1->GetRCurr()*f.Get()).pGetVec(), OH.GetCurrentStep());
+			}
 			Var_A1->put_rec((pNode1->GetXCurr() + pNode1->GetRCurr()*Arm1).pGetVec(), OH.GetCurrentStep());
 			Var_A2->put_rec((pNode2->GetXCurr() + pNode2->GetRCurr()*Arm2).pGetVec(), OH.GetCurrentStep());
 		}
 #endif // USE_NETCDF
 
 		if (OH.UseText(OutputHandler::FORCES)) {
-			Vec3 F(pNode1->GetRCurr()*f.Get());
+			Vec3 F;
+			if (fToBeOutput() & StructuralForce::OUTPUT_REL) {
+				F = f.Get();
+			} else {
+				F = pNode1->GetRCurr()*f.Get();
+			}
+
 			OH.Forces()
 				<< GetLabel()
 				<< " " << pNode1->GetLabel()
@@ -2294,7 +2348,7 @@ AbsoluteInternalCouple::OutputPrepare(OutputHandler& OH)
 			// joint sub-data
 			os << '.';
 			Var_F = OH.CreateVar<Vec3>(os.str() + "M", "Nm",
-				"couple components (x, y, z)");
+				"global couple components (x, y, z)");
 		}
 #endif // USE_NETCDF
 	}
@@ -2519,8 +2573,14 @@ FollowerInternalCouple::OutputPrepare(OutputHandler& OH)
 
 			// joint sub-data
 			os << '.';
-			Var_F = OH.CreateVar<Vec3>(os.str() + "M", "Nm",
-				"couple components (x, y, z)");
+			if (fToBeOutput() & StructuralForce::OUTPUT_REL) {
+				Var_F = OH.CreateVar<Vec3>(os.str() + "m", "Nm",
+					"local couple components (x, y, z)");
+
+			} else {
+				Var_F = OH.CreateVar<Vec3>(os.str() + "M", "Nm",
+					"global couple components (x, y, z)");
+			}
 		}
 #endif // USE_NETCDF
 	}
@@ -2532,12 +2592,22 @@ FollowerInternalCouple::Output(OutputHandler& OH) const
 	if (bToBeOutput()) {
 #ifdef USE_NETCDF
 		if (OH.UseNetCDF(OutputHandler::FORCES)) {
-			Var_F->put_rec((pNode1->GetRCurr()*f.Get()).pGetVec(), OH.GetCurrentStep());
+			if (fToBeOutput() & StructuralForce::OUTPUT_REL) {
+				Var_F->put_rec(f.Get().pGetVec(), OH.GetCurrentStep());
+			} else {
+				Var_F->put_rec((pNode1->GetRCurr()*f.Get()).pGetVec(), OH.GetCurrentStep());
+			}
 		}
 #endif // USE_NETCDF
 
 		if (OH.UseText(OutputHandler::FORCES)) {
-			Vec3 F(pNode1->GetRCurr()*f.Get());
+			Vec3 F;
+			if (fToBeOutput() & StructuralForce::OUTPUT_REL) {
+				F = f.Get();
+			} else {
+				F = pNode1->GetRCurr()*f.Get();
+			}
+
 			OH.Forces()
 				<< GetLabel()
 				<< " " << pNode1->GetLabel()
@@ -2761,8 +2831,17 @@ ReadStructuralForce(DataManager* pDM,
 		}
 	}
 
+	bool bOutRel(false);
+	if (bFollower && HP.IsKeyWord("output" "relative")) {
+		bOutRel = true;
+	}
+
 	flag fOut = pDM->fReadOutput(HP, Elem::FORCE);
 
+	if (bOutRel) {
+		fOut |= StructuralForce::OUTPUT_REL;
+	}
+
 	/* Alloca la forza */
 	if (!bCouple) {
 		if (!bFollower) {
@@ -2857,6 +2936,10 @@ ReadStructuralForce(DataManager* pDM,
 		os << ' ' << pDispNode2->GetLabel() << ' ' << Arm2;
 	}
 
+	if (bFollower && (pEl->fToBeOutput() & StructuralForce::OUTPUT_REL)) {
+		os << " output_relative";
+	}
+
 	os << std::endl;
 
 	return pEl;
