@@ -1,9 +1,9 @@
-/* $Header: /var/cvs/mbdyn/mbdyn/mbdyn-1.0/mbdyn/struct/strforce_impl.h,v 1.11 2016/01/15 09:21:33 zanoni Exp $ */
+/* $Header: /var/cvs/mbdyn/mbdyn/mbdyn-1.0/mbdyn/struct/strforce_impl.h,v 1.13 2017/06/18 23:07:37 masarati Exp $ */
 /*
  * MBDyn (C) is a multibody analysis code.
  * http://www.mbdyn.org
  *
- * Copyright (C) 1996-2015
+ * Copyright (C) 1996-2017
  *
  * Pierangelo Masarati	<masarati@aero.polimi.it>
  * Paolo Mantegazza	<mantegazza@aero.polimi.it>
@@ -171,6 +171,11 @@ public:
 /* StructuralForce - begin */
 
 class StructuralForce : virtual public Elem, public Force {
+public:
+	enum {
+		OUTPUT_REL = ToBeOutput::OUTPUT_PRIVATE
+	};
+
 protected:
 	TplDriveOwner<Vec3> f;
 	const StructNode* pNode;
