@@ -2,7 +2,7 @@
  * MBDyn (C) is a multibody analysis code.
  * http://www.mbdyn.org
  *
- * Copyright (C) 1996-2015
+ * Copyright (C) 1996-2017
  *
  * Pierangelo Masarati	<masarati@aero.polimi.it>
  * Paolo Mantegazza	<mantegazza@aero.polimi.it>
@@ -581,21 +581,31 @@ TotalEquation::Restart(std::ostream& out) const
 {
 	Joint::Restart(out) << ", total equation, "
 		<< pNode1->GetLabel() << ", "
-			<< "position, " << f1.Write(out, ", ") << ", "
+			<< "position, ";
+			f1.Write(out, ", ") << ", "
 			<< "position orientation, "
-				"1 , ", R1h.GetVec(1).Write(out, ", ") << ", "
-				"2 , ", R1h.GetVec(2).Write(out, ", ") << ", "
+				"1 , "; 
+				R1h.GetVec(1).Write(out, ", ") << ", "
+				"2 , "; 
+				R1h.GetVec(2).Write(out, ", ") << ", "
 			<< "rotation orientation, "
-				"1 , ", R1hr.GetVec(1).Write(out, ", ") << ", "
-				"2 , ", R1hr.GetVec(2).Write(out, ", ") << ", "
+				"1 , "; 
+				R1hr.GetVec(1).Write(out, ", ") << ", "
+				"2 , ";
+				R1hr.GetVec(2).Write(out, ", ") << ", "
 		<< pNode2->GetLabel() << ", "
-			<< "position, " << f2.Write(out, ", ") << ", "
+			<< "position, "; 
+			f2.Write(out, ", ") << ", "
 			<< "position orientation, "
-				"1 , ", R2h.GetVec(1).Write(out, ", ") << ", "
-				"2 , ", R2h.GetVec(2).Write(out, ", ") << ", "
+				"1 , ";
+				R2h.GetVec(1).Write(out, ", ") << ", "
+				"2 , ";
+				R2h.GetVec(2).Write(out, ", ") << ", "
 			<< "rotation orientation, "
-				"1 , ", R2hr.GetVec(1).Write(out, ", ") << ", "
-				"2 , ", R2hr.GetVec(2).Write(out, ", ");
+				"1 , ";
+				R2hr.GetVec(1).Write(out, ", ") << ", "
+				"2 , ";
+				R2hr.GetVec(2).Write(out, ", ");
 
 	if (bPosActive[0] || bPosActive[1] || bPosActive[2]) {
 		out << ", position constraint";
@@ -1559,21 +1569,31 @@ TotalReaction::Restart(std::ostream& out) const
 {
 	Joint::Restart(out) << ", total equation, "
 		<< pNode1->GetLabel() << ", "
-			<< "position, " << f1.Write(out, ", ") << ", "
+			<< "position, ";
+			f1.Write(out, ", ") << ", "
 			<< "position orientation, "
-				"1 , ", R1h.GetVec(1).Write(out, ", ") << ", "
-				"2 , ", R1h.GetVec(2).Write(out, ", ") << ", "
+				"1 , ";
+				R1h.GetVec(1).Write(out, ", ") << ", "
+				"2 , ";
+				R1h.GetVec(2).Write(out, ", ") << ", "
 			<< "rotation orientation, "
-				"1 , ", R1hr.GetVec(1).Write(out, ", ") << ", "
-				"2 , ", R1hr.GetVec(2).Write(out, ", ") << ", "
+				"1 , ";
+				R1hr.GetVec(1).Write(out, ", ") << ", "
+				"2 , ";
+				R1hr.GetVec(2).Write(out, ", ") << ", "
 		<< pNode2->GetLabel() << ", "
-			<< "position, " << f2.Write(out, ", ") << ", "
+			<< "position, ";
+			f2.Write(out, ", ") << ", "
 			<< "position orientation, "
-				"1 , ", R2h.GetVec(1).Write(out, ", ") << ", "
-				"2 , ", R2h.GetVec(2).Write(out, ", ") << ", "
+				"1 , ";
+				R2h.GetVec(1).Write(out, ", ") << ", "
+				"2 , ";
+				R2h.GetVec(2).Write(out, ", ") << ", "
 			<< "rotation orientation, "
-				"1 , ", R2hr.GetVec(1).Write(out, ", ") << ", "
-				"2 , ", R2hr.GetVec(2).Write(out, ", ");
+				"1 , ";
+				R2hr.GetVec(1).Write(out, ", ") << ", "
+				"2 , ";
+				R2hr.GetVec(2).Write(out, ", ");
 
 	if (bPosActive[0] || bPosActive[1] || bPosActive[2]) {
 		out << ", position constraint";
